@@ -26,9 +26,13 @@
 /* Define this if you want S/Key support in the login program */
 #undef SKEY
 
+/* Define this to the path of the mail spool directory */
+#undef KRB4_MAILDIR
+
 /* Define this if `struct sockaddr' includes sa_len */
 #undef SOCKADDR_HAS_SA_LEN
 
+
 @BOTTOM@
 
 #ifdef __STDC__
@@ -50,9 +54,9 @@
 
 #define KEYFILE		"/etc/srvtab"
 
-#define MKEYFILE	"/.k"
-#define DBM_FILE	"/var/kerberos/principal"
-#define DEFAULT_ACL_DIR	"/var/kerberos"
+#define KRBDIR		"/var/kerberos"
+#define DBM_FILE	KRBDIR "/principal"
+#define DEFAULT_ACL_DIR	KRBDIR
 
 #define KRBLOG		"/var/log/kerberos.log"	/* master server  */
 #define KRBSLAVELOG	"/var/log/kerberos_slave.log" /* slave server  */
@@ -81,6 +85,16 @@
  */
 #undef HAVE_NEW_DB
 
+/* Define this if you have a working getmsg */
+#undef HAVE_GETMSG
+
+/* Define to enable new master key code */
+#undef RANDOM_MKEY
+
+/* Location of the master key file, default value lives in <kdc.h> */
+#undef MKEYFILE
+
+
 /*
  * Atleast HPUX does not have setreuid and seteuid
  */
