@@ -15,7 +15,7 @@
 
 #include "adm_locl.h"
 
-RCSID("$Header: /afs/nada.kth.se/src/packages/kth-krb/SourceRepository/krb4/admin/kdb_edit.c,v 1.11 1996/02/10 12:59:14 assar Exp $");
+RCSID("$Header: /src/packages/kth-krb/SourceRepository/krb4/admin/kdb_edit.c,v 1.12 1996/03/13 14:25:00 assar Exp $");
 
 #ifdef DEBUG
 extern  kerb_debug;
@@ -374,16 +374,6 @@ main(int argc, char **argv)
 	}
     }
 
-#ifdef	notdef
-    no_core_dumps();		/* diddle signals to avoid core dumps! */
-
-    /* ignore whatever is reasonable */
-    signal(SIGHUP, SIG_IGN);
-    signal(SIGINT, SIG_IGN);
-    signal(SIGTSTP, SIG_IGN);
-
-#endif
-
     if (kdb_get_master_key ((nflag == 0) ? KDB_GET_PROMPT : 0, 
 			    &master_key, master_key_schedule) != 0) {
       fprintf (stdout, "Couldn't read master key.\n");
@@ -417,31 +407,3 @@ main(int argc, char **argv)
     cleanup();
     return 0;
 }
-
-#if 0
-static void
-sig_exit(sig, code, scp)
-    int     sig, code;
-    struct sigcontext *scp;
-{
-    cleanup();
-    fprintf(stderr,
-	"\nSignal caught, sig = %d code = %d old pc = 0x%X \nexiting",
-        sig, code, scp->sc_pc);
-    exit(-1);
-}
-
-static void
-no_core_dumps()
-{
-    signal(SIGQUIT, sig_exit);
-    signal(SIGILL, sig_exit);
-    signal(SIGTRAP, sig_exit);
-    signal(SIGIOT, sig_exit);
-    signal(SIGEMT, sig_exit);
-    signal(SIGFPE, sig_exit);
-    signal(SIGBUS, sig_exit);
-    signal(SIGSEGV, sig_exit);
-    signal(SIGSYS, sig_exit);
-}
-#endif
