@@ -10,7 +10,7 @@
 
 #include "adm_locl.h"
 
-RCSID("$Header: /afs/nada.kth.se/src/packages/kth-krb/SourceRepository/krb4/admin/kdb_init.c,v 1.11 1996/02/10 12:59:15 assar Exp $");
+RCSID("$Header: /src/packages/kth-krb/SourceRepository/krb4/admin/kdb_init.c,v 1.12 1996/03/24 06:44:33 d91-jda Exp $");
 
 enum ap_op {
     NULL_KEY,			/* setup null keys */
@@ -133,8 +133,13 @@ main(int argc, char **argv)
 		progname, realm);
 	exit(1);
     }
+#ifndef RANDOM_MKEY
     printf("You will be prompted for the database Master Password.\n");
     printf("It is important that you NOT FORGET this password.\n");
+#else
+    printf("To generate a master key, please enter some random data.\n");
+    printf("You do not have to remember this.\n");
+#endif
     fflush(stdout);
 
     if (kdb_get_master_key (KDB_GET_TWICE, &master_key,
@@ -143,6 +148,14 @@ main(int argc, char **argv)
       exit (-1);
     }
 
+#ifdef RANDOM_MKEY
+    if(kdb_kstash(&master_key, MKEYFILE) < 0){
+      perror("Error writing master key");
+      exit(1);
+    }
+    fprintf(stderr, "Wrote master key to %s\n", MKEYFILE);
+#endif
+
     /* Initialize non shared random sequence */
     des_init_random_number_generator(&master_key);
 
