@@ -15,7 +15,7 @@
 
 #include "adm_locl.h"
 
-RCSID("$Header: /afs/nada.kth.se/src/packages/kth-krb/SourceRepository/krb4/admin/kdb_util.c,v 1.10 1996/02/10 12:59:16 assar Exp $");
+RCSID("$Header: /src/packages/kth-krb/SourceRepository/krb4/admin/kdb_util.c,v 1.11 1996/03/24 06:44:59 d91-jda Exp $");
 
 static char *prog; 
 
@@ -282,7 +282,11 @@ clear_secrets (void)
 static void
 convert_new_master_key (char *db_file, FILE *out)
 {
-
+#ifdef RANDOM_MKEY
+  fprintf(stderr, "Sorry, this function is not available with "
+	  "the new master key scheme.\n");
+  exit(1);
+#else
   printf ("\n\nEnter the CURRENT master key.");
   if (kdb_get_master_key (KDB_GET_PROMPT, &master_key,
 			  master_key_schedule) != 0) {
@@ -305,6 +309,12 @@ convert_new_master_key (char *db_file, FILE *out)
   }
 
   dump_db (db_file, out, convert_key_new_master);
+  {
+    char fname[128];
+    sprintf(fname, "%s.new", MKEYFILE);
+    kdb_kstash(&new_master_key, fname);
+  }
+#endif /* RANDOM_MKEY */
 }
 
 static void
