@@ -10,7 +10,7 @@
 
 #include "adm_locl.h"
 
-RCSID("$Header: /afs/nada.kth.se/src/packages/kth-krb/SourceRepository/krb4/admin/kstash.c,v 1.4 1996/02/10 12:59:17 assar Exp $");
+RCSID("$Header: /src/packages/kth-krb/SourceRepository/krb4/admin/kstash.c,v 1.5 1996/03/24 06:45:18 d91-jda Exp $");
 
 /* change this later, but krblib_dbm needs it for now */
 char   *progname;
@@ -30,6 +30,7 @@ int
 main(int argc, char **argv)
 {
     long    n;
+    int ret = 0;
     if ((n = kerb_init())) {
 	fprintf(stderr, "Kerberos db and cache init failed = %ld\n", n);
 	exit(1);
@@ -37,31 +38,23 @@ main(int argc, char **argv)
 
     if (kdb_get_master_key (KDB_GET_PROMPT, &master_key,
 			    master_key_schedule) != 0) {
-      fprintf (stderr, "%s: Couldn't read master key.\n", argv[0]);
-      fflush (stderr);
-      clear_secrets();
-      exit (-1);
+	fprintf (stderr, "%s: Couldn't read master key.\n", argv[0]);
+	fflush (stderr);
+	clear_secrets();
+	exit (-1);
     }
 
     if (kdb_verify_master_key (&master_key, master_key_schedule, stderr) < 0) {
-      clear_secrets();
-      exit (-1);
+	clear_secrets();
+	exit (-1);
     }
 
-    kfile = open(MKEYFILE, O_TRUNC | O_RDWR | O_CREAT, 0600);
-    if (kfile < 0) {
-	clear_secrets();
-	fprintf(stderr, "\n\07\07%s: Unable to open master key file\n",
-		argv[0]);
-	exit(1);
-    }
-    if (write(kfile, (char *) master_key, 8) < 0) {
-	clear_secrets();
-	fprintf(stderr, "\n%s: Write I/O error on master key file\n",
-		argv[0]);
-	exit(1);
-    }
-    (void) close(kfile);
+    ret = kdb_kstash(&master_key, MKEYFILE);
+    if(ret < 0)
+	perror("Error writing master key");
+    else
+	fprintf(stderr, "Wrote master key to %s\n", MKEYFILE);
+    
     clear_secrets();
-    return 0;
+    return ret;
 }
