@@ -8,16 +8,20 @@
 #define SYSV_ENV
 #define ENV_USER
 
+#include "config.h"
+#include "protos.h"
+
 /* Any better way to test this? */
 #if SunOS == 5
 /* #define SYSV_SHADOW done below */
 /* #define SYSV_ENV done above */
 /* #define ENV_USER done above */
-#define NO_MOTD
 #endif
 
-#include "config.h"
-#include "protos.h"
+/* Any better way to test NO_MOTD? */
+#if (SunOS == 5) || defined(__hpux)
+#define NO_MOTD
+#endif
 
 #ifdef HAVE_SHADOW_H
 #define SYSV_SHADOW
@@ -53,6 +57,9 @@ extern int optind, opterr;
 #if defined(HAVE_SYS_IOCTL_H) && SunOS != 4
 #include <sys/ioctl.h>
 #endif
+#ifdef HAVE_SYS_IOCCOM_H
+#include <sys/ioccom.h>
+#endif
 
 #ifndef NCARGS
 #define NCARGS  0x100000 /* (absolute) max # characters in exec arglist */
@@ -111,6 +118,24 @@ extern int optind, opterr;
 #define LOG_AUTHPRIV LOG_AUTH
 #endif
 
+/* Strange ioctls that are not always defined */
+
+#ifndef TIOCPKT_FLUSHWRITE
+#define TIOCPKT_FLUSHWRITE      0x02
+#endif
+ 
+#ifndef TIOCPKT_NOSTOP
+#define TIOCPKT_NOSTOP  0x10
+#endif
+ 
+#ifndef TIOCPKT_DOSTOP
+#define TIOCPKT_DOSTOP  0x20
+#endif
+
+#ifndef TIOCPKT
+#define TIOCPKT		_IOW('t', 112, int)   /* pty: set/clear packet mode */
+#endif
+
 #ifdef HAVE_LASTLOG_H
 #include <lastlog.h>
 #endif
@@ -178,14 +203,42 @@ int forkpty ();
 #endif
 
 #include "err.h"
+#ifdef HAVE_PATHS_H
+#include <paths.h>
+#endif
+#ifdef HAVE_MAILLOCK_H
+#include <maillock.h>
+#endif
 #include "pathnames.h"
 
 #ifndef MAX
 #define MAX(a, b) ((a) > (b) ? (a) : (b))
 #endif
 
-#ifndef HAVE_GETUSERSHELL
 char *getusershell __P((void));
-#endif
+
+char *crypt __P((const char *, const char *));
 
 void stty_default __P((void));
+
+#ifndef NeXT
+typedef RETSIGTYPE (*SigAction)(/* int??? */);
+
+SigAction signal(int iSig, SigAction pAction);
+#endif
+
+int utmpx_login(char *line, char *user, char *host);
+
+void sysv_newenv(int argc, char **argv, struct passwd *pwd,
+		 char *term, int pflag);
+
+#ifndef HAVE_SETENV
+int setenv(const char *var, const char *val, int rewrite);
+#endif
+
+int login_access(char *user, char *from);
+#ifndef HAVE_IRUSEROK
+int iruserok(u_int32_t raddr, int superuser, const char *ruser,
+	     const char *luser);
+#endif
+void fatal(int f, const char *msg, int syserr);
