@@ -2,7 +2,7 @@
 
 #ifndef HAVE_FORKPTY
 
-RCSID("$Id: forkpty.c,v 1.29 1996/02/11 17:21:40 bg Exp $");
+RCSID("$Id: forkpty.c,v 1.35 1996/03/24 22:38:42 bg Exp $");
 
 /* Systems where rlogind has been tested */
 #if 1 || (defined(sun) && !defined(__svr4__)) || defined(__hpux) || defined(__linux) || defined(__sgi__) || defined(__NetBSD__) || defined(_AIX)
@@ -41,7 +41,7 @@ static char *ptsname(int fd)
 #endif
 
 #ifndef HAVE_VHANGUP
-void vhangup() { return; }
+#define vhangup() (0)
 #endif
 
 #ifndef HAVE_REVOKE
@@ -58,9 +58,18 @@ revoke(char *line)
     ofun = signal(SIGHUP, SIG_IGN);
     vhangup();
     signal(SIGHUP, ofun);
-#if 0
-    close(slave);		/* This seems not to work on SGI */
-#endif
+    /*
+     * Some systems (atleast SunOS4) want to have the slave end open
+     * at all times to prevent a race in the child. Login will close
+     * it so it should really not be a problem. However for the
+     * paranoid we use the close on exec flag so it will only be open
+     * in the parent. Additionally since this will be the controlling
+     * tty of rlogind the final vhangup() in rlogind should hangup all
+     * processes. A working revoke would of course have been prefered
+     * though (sigh).
+     */
+    fcntl(slave, F_SETFD, 1);
+    /* close(slave); */
 }
 #endif
 
@@ -243,14 +252,16 @@ forkpty(int *ptrfdm, char *slave_name, struct termios *slave_termios, struct win
     if (slave_name != NULL)
 	strcpy(slave_name, pts_name);	/* Return name of slave */
 
-    revoke(slave_name);
-    if ( (pid = fork()) < 0)
+    pid = fork();
+    if (pid < 0)
 	return(-1);
     else if (pid == 0) {		/* Child */
 	if (setsid() < 0)
-	    return -1;
+	    fatal(0, "setsid() failure", errno);
 
-#if defined(NeXT)
+        revoke(slave_name);
+
+#if defined(NeXT) || defined(ultrix)
 	/* The NeXT is severely broken, this makes things slightly
 	 * better but we still doesn't get a working pty. If there
 	 * where a TIOCSCTTY we could perhaps fix things but... The
@@ -269,6 +280,15 @@ forkpty(int *ptrfdm, char *slave_name, struct termios *slave_termios, struct win
 	/* !CIBAUD to avoid doing this under SunOS */
 	if (ioctl(fds, TIOCSCTTY, (char *) 0) < 0)
 	    return -1;
+#endif
+#if defined(NeXT)
+	{
+	    int t = open("/dev/tty", O_RDWR);
+	    if (t < 0)
+	        fatal(0, "Failed to open /dev/tty", errno);
+	    close(fds);
+	    fds = t;
+	}
 #endif
 	/* Set slave's termios and window size */
 	if (slave_termios != NULL) {
