@@ -35,7 +35,7 @@
 
 #include "bsd_locl.h"
 
-RCSID("$Id: krcmd.c,v 1.5 1996/01/02 15:55:42 bg Exp $");
+RCSID("$Id: krcmd.c,v 1.7 1996/03/11 09:21:28 bg Exp $");
 
 #define	SERVICE_NAME	"rcmd"
 
@@ -76,7 +76,7 @@ krcmd(char **ahost, u_short rport, char *remuser, char *cmd, int *fd2p, char *re
 		if (rstar_no_warn == 0)
 			rstar_no_warn = "";
 		if (strncmp(rstar_no_warn, "yes", 3) != 0)
-			fprintf(stderr, "krcmd: %s\n", krb_err_txt[err]);
+			fprintf(stderr, "krcmd: %s\n", krb_get_err_text(err));
 		return(-1);
 	}
 	if (err < 0)
@@ -113,7 +113,7 @@ krcmd_mutual(char **ahost, u_short rport, char *remuser, char *cmd, int *fd2p, c
 	);
 
 	if (err > KSUCCESS && err < MAX_KRB_ERRORS) {
-		fprintf(stderr, "krcmd_mutual: %s\n", krb_err_txt[err]);
+		fprintf(stderr, "krcmd_mutual: %s\n", krb_get_err_text(err));
 		return(-1);
 	}
 
