@@ -39,9 +39,9 @@
 
 #include "bsd_locl.h"
 
-RCSID("$Id: login.c,v 1.41 1996/02/10 17:36:15 assar Exp $");
+RCSID("$Id: login.c,v 1.45 1996/03/24 15:13:33 bg Exp $");
 
-#ifdef	xSKEY
+#ifdef	xSKEY			/* Don't bother to find this header file. */
 #include <skey.h>
 #endif
 
@@ -60,6 +60,7 @@ void	 sigint __P((int));
 void	 sleepexit __P((int));
 char	*stypeof __P((char *));
 void	 timedout __P((int));
+int	 doremotelogin __P((char *));
 void     login_fbtab __P((char *, uid_t, gid_t));
 #ifdef KERBEROS
 int	 klogin __P((struct passwd *, char *, char *, char *));
@@ -140,10 +141,8 @@ main(argc, argv)
 	int argc;
 	char *argv[];
 {
-	extern char **environ;
 	struct group *gr;
 	struct stat st;
-	struct timeval tp;
 	struct utmp utmp;
 	int ask, ch, cnt, fflag, hflag, pflag, quietlog, rootlogin, rval;
 	int rflag;
@@ -839,10 +838,12 @@ dolastlog(quiet)
                                     24-5, (char *)ctime(&ll.ll_time));
                                 if (*ll.ll_host != '\0') {
                                         printf("from %.*s\n",
-                                            sizeof(ll.ll_host), ll.ll_host);
+                                            (int)sizeof(ll.ll_host),
+					       ll.ll_host);
                                 } else
                                         printf("on %.*s\n",
-                                            sizeof(ll.ll_line), ll.ll_line);
+                                            (int)sizeof(ll.ll_line),
+					       ll.ll_line);
                         }
                 }
                 (void)lseek(fd, (off_t)pwd->pw_uid * sizeof(ll), SEEK_SET);
@@ -920,21 +921,7 @@ stypeof(ttyid)
     }
 }
 
-doremotelogin(host)
-        char *host;
-{
-        getstr(rusername, sizeof (rusername), "remuser");
-        getstr(lusername, sizeof (lusername), "locuser");
-        getstr(term, sizeof(term), "Terminal type");
-        pwd = getpwnam(lusername);
-        if (pwd == NULL)
-                return(-1);
-        return(ruserok(host, (pwd->pw_uid == 0), rusername, lusername));
-}
- 
-getstr(buf, cnt, err)
-        char *buf, *err;
-        int cnt;
+void getstr(char *buf, int cnt, char *err)
 {
         char ch;
  
@@ -949,9 +936,19 @@ getstr(buf, cnt, err)
         } while (ch);
 }
 
+int doremotelogin(char *host)
+{
+        getstr(rusername, sizeof (rusername), "remuser");
+        getstr(lusername, sizeof (lusername), "locuser");
+        getstr(term, sizeof(term), "Terminal type");
+        pwd = getpwnam(lusername);
+        if (pwd == NULL)
+                return(-1);
+        return(ruserok(host, (pwd->pw_uid == 0), rusername, lusername));
+}
+ 
 void
-sleepexit(eval)
-	int eval;
+sleepexit(int eval)
 {
 
 	(void)sleep(5);
@@ -959,8 +956,7 @@ sleepexit(eval)
 }
 
 void
-login(ut)
-        struct utmp *ut;
+login(struct utmp *ut)
 {
         int fd;
 
