@@ -9,12 +9,9 @@
 
 #include "bsd_locl.h"
 
-RCSID("$Id: login_access.c,v 1.6 1996/01/02 15:55:45 bg Exp $");
+RCSID("$Id: login_access.c,v 1.8 1996/03/13 14:26:49 assar Exp $");
 
 #ifdef LOGIN_ACCESS
-#if 0
-static char sccsid[] = "%Z% %M% %I% %E% %U%";
-#endif
 
  /* Delimiters for fields and for lists of users, ttys or hosts. */
 
@@ -26,17 +23,14 @@ static char sep[] = ", \t";		/* list-element separator */
 #define YES             1
 #define NO              0
 
-static int list_match();
-static int user_match();
-static int from_match();
-static int string_match();
+static int list_match(char *list, char *item, int (*match_fn)());
+static int user_match(char *tok, char *string);
+static int from_match(char *tok, char *string);
+static int string_match(char *tok, char *string);
 
 /* login_access - match username/group and host/tty with access control file */
 
-int
-login_access(user, from)
-char   *user;
-char   *from;
+int login_access(char *user, char *from)
 {
     FILE   *fp;
     char    line[BUFSIZ];
@@ -95,10 +89,7 @@ char   *from;
 
 /* list_match - match an item against a list of tokens with exceptions */
 
-static int list_match(list, item, match_fn)
-char   *list;
-char   *item;
-int   (*match_fn) ();
+static int list_match(char *list, char *item, int (*match_fn)())
 {
     char   *tok;
     int     match = NO;
@@ -148,9 +139,7 @@ char   *user;
 
 /* user_match - match a username against one token */
 
-static int user_match(tok, string)
-char   *tok;
-char   *string;
+static int user_match(char *tok, char *string)
 {
     struct group *group;
     int     i;
@@ -175,9 +164,7 @@ char   *string;
 
 /* from_match - match a host or tty against a list of tokens */
 
-static int from_match(tok, string)
-char   *tok;
-char   *string;
+static int from_match(char *tok, char *string)
 {
     int     tok_len;
     int     str_len;
@@ -211,9 +198,7 @@ char   *string;
 
 /* string_match - match a string against one token */
 
-static int string_match(tok, string)
-char   *tok;
-char   *string;
+static int string_match(char *tok, char *string)
 {
 
     /*
