@@ -31,7 +31,7 @@
  * SUCH DAMAGE.
  *
  *	from: @(#)pathnames.h	5.2 (Berkeley) 4/9/90
- *	$Id: pathnames.h,v 1.15 1996/01/31 20:33:55 bg Exp $
+ *	$Id: pathnames.h,v 1.18 1996/03/22 16:09:20 bg Exp $
  */
 
 /******* First fix default path, we stick to _PATH_DEFPATH everywhere */
@@ -122,9 +122,16 @@
 #define _PATH_CHPASS "/usr/bin/passwd"
 #endif /* _PATH_CHPASS */
 
+#ifndef KRB4_MAILDIR
 #ifndef _PATH_MAILDIR
+#ifdef MAILDIR
+#define _PATH_MAILDIR MAILDIR
+#else
 #define _PATH_MAILDIR "/usr/spool/mail"
+#endif
 #endif /* _PATH_MAILDIR */
+#define KRB4_MAILDIR _PATH_MAILDIR
+#endif
 
 #ifndef _PATH_LASTLOG
 #define _PATH_LASTLOG		"/var/adm/lastlog"
