@@ -35,7 +35,7 @@
 
 #include "bsd_locl.h"
 
-RCSID("$Id: rcp.c,v 1.15 1996/02/04 15:05:51 assar Exp $");
+RCSID("$Id: rcp.c,v 1.19 1996/03/24 06:56:41 assar Exp $");
 
 /* Globals */
 char *__progname;
@@ -94,7 +94,7 @@ send_auth(char *h, char *r)
 			    &foreign, "KCMDV0.1")) != KSUCCESS)
 	{
 	    fprintf(stderr, "krb_sendauth failure: %s\n", 
-		    krb_err_txt[status]);
+		    krb_get_err_text(status));
 	    exit(1);
 	}
 }
@@ -118,13 +118,13 @@ answer_auth()
 	    perror("getperrname");
 	    exit(1);
 	}
-    strcpy(inst, "*");
+    k_getsockinst(rem, inst);
     opts = KOPT_DO_MUTUAL;
     if ((status = krb_recvauth(opts, rem, &ticket, SERVICE_NAME, inst, &foreign, &local, 
 			       &kdata, "", schedule, v)) != KSUCCESS)
 	{
 	    fprintf(stderr, "krb_recvauth failure: %s\n", 
-		    krb_err_txt[status]);
+		    krb_get_err_text(status));
 	    exit(1);
 	}
 }
@@ -459,7 +459,7 @@ again:
 		    (struct sockaddr_in *) NULL, /* foreign addr not used */
 		    0L);	/* authopts */
 		if (err > KSUCCESS && err < MAX_KRB_ERRORS) {
-			fprintf(stderr, "kcmd: %s\n", krb_err_txt[err]);
+			fprintf(stderr, "kcmd: %s\n", krb_get_err_text(err));
 			rem = -1;
 		} else if (err < 0)
 		    rem = -1;
@@ -562,7 +562,7 @@ toremote(char *targ, int argc, char **argv)
 #ifdef IP_TOS
 				tos = IPTOS_THROUGHPUT;
 				if (setsockopt(rem, IPPROTO_IP, IP_TOS,
-				    &tos, sizeof(int)) < 0)
+				    (void *)&tos, sizeof(int)) < 0)
 					warn("TOS (ignored)");
 #endif /* IP_TOS */
 				if (doencrypt)
@@ -874,7 +874,8 @@ tolocal(int argc, char **argv)
 		(void)seteuid(userid);
 #ifdef IP_TOS
 		tos = IPTOS_THROUGHPUT;
-		if (setsockopt(rem, IPPROTO_IP, IP_TOS, &tos, sizeof(int)) < 0)
+		if (setsockopt(rem, IPPROTO_IP, IP_TOS, (void *)&tos,
+			       sizeof(int)) < 0)
 			warn("TOS (ignored)");
 #endif /* IP_TOS */
 		if (doencrypt)
