@@ -38,7 +38,7 @@
  */
 #include "bsd_locl.h"
 
-RCSID("$Id: rlogin.c,v 1.26 1996/02/07 10:47:57 d91-jda Exp $");
+RCSID("$Id: rlogin.c,v 1.28 1996/03/24 16:52:19 bg Exp $");
 
 #include <termios.h>
 
@@ -158,24 +158,6 @@ int		get_window_size __P((int, struct winsize *));
 
 int child;
 
-/* trap a signal, unless it is being ignored. */
-static void
-setsignal(int sig)
-{
-	sigset_t omask, sigmsk;
-
-	sigemptyset(&sigmsk);
-	sigaddset(&sigmsk, sig);
-	if (sigprocmask(SIG_BLOCK, &sigmsk, &omask) != 0)
-	    perror("sigprocmask");
-
-	if (signal(sig, exit) == SIG_IGN)
-		(void)signal(sig, SIG_IGN);
-
-	if (sigprocmask(SIG_SETMASK, &omask, 0) != 0)
-	    perror("sigprocmask");
-}
-
 static void
 echo(register char c)
 {
@@ -243,8 +225,9 @@ done(int status)
 	exit(status);
 }
 
-static void
-catch_child(int signo)
+static
+RETSIGTYPE
+catch_child()
 {
 	int status;
 	int pid;
@@ -266,8 +249,9 @@ msg(char *str)
 	(void)fprintf(stderr, "rlogin: %s\r\n", str);
 }
 
-static void
-oob_real(int signo)
+static
+RETSIGTYPE
+oob_real()
 {
 	struct termios tty;
 	int atmark, n, out, rcvd;
@@ -333,15 +317,12 @@ oob_real(int signo)
 
 /* reader: read from remote: line -> 1 */
 static int
-reader(sigset_t omask)
+reader(void)
 {
 	int n, remaining;
 	char *bufp;
 
-	(void)signal(SIGTTOU, SIG_IGN);
 	(void)setjmp(rcvtop);
-	if (sigprocmask(SIG_SETMASK, &omask, 0) != 0)
-	    perror("sigprocmask");
 	bufp = rcvbuf;
 	for (;;) {
 	        fd_set readfds, exceptfds;
@@ -433,8 +414,9 @@ sendwindow(void)
 		(void)write(rem, obuf, sizeof(obuf));
 }
 
-static void
-sigwinch(int signo)
+static
+RETSIGTYPE
+sigwinch()
 {
 	struct winsize ws;
 
@@ -443,7 +425,6 @@ sigwinch(int signo)
 		winsize = ws;
 		sendwindow();
 	}
-       signal(SIGWINCH, sigwinch);
 }
 
 static void
@@ -546,52 +527,23 @@ writer(void)
 	}
 }
 
-static void
-doit(sigset_t omask)
+static
+RETSIGTYPE
+lostpeer()
 {
-
-	(void)signal(SIGINT, SIG_IGN);
-	setsignal(SIGHUP);
-	setsignal(SIGQUIT);
-	mode(1);
-	parent = getpid();
-	child = fork();
-	if (child == -1) {
-		(void)fprintf(stderr, "rlogin: fork: %s.\n", k_strerror(errno));
-		done(1);
-	}
-	if (child == 0) {
-		if (reader(omask) == 0) {
-			msg("connection closed.");
-			exit(0);
-		}
-		sleep(1);
-		msg("\aconnection closed.");
-		exit(1);
-	}
-
-	/*
-	 * We may still own the socket, and may have a pending OOB (or might
-	 * receive one soon) that we really want to send to the reader.  When
-	 * one of these comes in, the trap copytochild simply copies such
-	 * signals to the child. We can now unblock OOB and SIGUSR1
-	 * that were set above.
-	 */
-	if (sigprocmask(SIG_SETMASK, &omask, 0) != 0)
-	    perror("sigprocmask");
-	(void)signal(SIGCHLD, catch_child);
-	writer();
-	msg("closed connection.");
-	done(0);
+	(void)signal(SIGPIPE, SIG_IGN);
+	msg("\aconnection closed.");
+	done(1);
 }
 
 /*
- * This is called when the reader process gets the out-of-band
- * (urgent) request to turn on the window-changing protocol. It is
- * signalled from the child(reader).
+ * This is called in the parent when the reader process gets the
+ * out-of-band (urgent) request to turn on the window-changing
+ * protocol. It is signalled from the child(reader).
  */
-static void
-sigusr1(int signo)
+static
+RETSIGTYPE
+sigusr1()
 {
         /*
 	 * Now we now daemon supports winsize hack,
@@ -601,11 +553,43 @@ sigusr1(int signo)
 }
 
 static void
-lostpeer(int signo)
+doit(void)
 {
-	(void)signal(SIGPIPE, SIG_IGN);
-	msg("\aconnection closed.");
-	done(1);
+	(void)signal(SIGINT, SIG_IGN);
+	(void)signal(SIGHUP, SIG_IGN);
+	(void)signal(SIGQUIT, SIG_IGN);
+
+	(void)signal(SIGCHLD, catch_child);
+
+	/*
+	 * Child sends parent this signal for window size hack.
+	 */
+	(void)signal(SIGUSR1, sigusr1);
+
+	(void)signal(SIGPIPE, lostpeer);
+
+	mode(1);
+	parent = getpid();
+	child = fork();
+	if (child == -1) {
+		(void)fprintf(stderr, "rlogin: fork: %s.\n", k_strerror(errno));
+		done(1);
+	}
+	if (child == 0) {
+	        (void)signal(SIGCHLD, SIG_IGN);
+	        (void)signal(SIGTTOU, SIG_IGN);
+		if (reader() == 0) {
+			msg("connection closed.");
+			exit(0);
+		}
+		sleep(1);
+		msg("\aconnection closed.");
+		exit(1);
+	}
+
+	writer();
+	msg("closed connection.");
+	done(0);
 }
 
 static void
@@ -674,7 +658,6 @@ main(int argc, char **argv)
 	struct passwd *pw;
 	int sv_port;
 	struct termios tty;
-	sigset_t omask;
 	int argoff, ch, dflag, one, uid;
 	char *host, *p, *user, term[1024];
 
@@ -758,14 +741,7 @@ main(int argc, char **argv)
 
 	(void)get_window_size(0, &winsize);
 
-	(void)signal(SIGPIPE, lostpeer);
-
-	/*
-	 * Child sends parent this signal for window size hack.
-	 */
-	(void)signal(SIGUSR1, sigusr1);
-
-try_connect:
+      try_connect:
 	if (use_kerberos) {
 		struct hostent *hp;
 
@@ -816,11 +792,11 @@ try_connect:
 		    k_strerror(errno));
 #ifdef IP_TOS
 	one = IPTOS_LOWDELAY;
-	if (setsockopt(rem, IPPROTO_IP, IP_TOS, (char *)&one, sizeof(int)) < 0)
+	if (setsockopt(rem, IPPROTO_IP, IP_TOS, (void *)&one, sizeof(int)) < 0)
 		perror("rlogin: setsockopt TOS (ignored)");
 #endif /* IP_TOS */
 
 	(void)setuid(uid);
-	doit(omask);
+	doit();
 	return 0;
 }
