@@ -42,7 +42,7 @@
 
 #include "bsd_locl.h"
 
-RCSID("$Id: rlogind.c,v 1.40 1996/02/11 17:32:54 bg Exp $");
+RCSID("$Id: rlogind.c,v 1.47 1996/03/24 16:38:03 bg Exp $");
 
 #include <termios.h>
 
@@ -318,14 +318,16 @@ int main(int argc, char **argv)
 	}
 	on = 1;
 	if (keepalive &&
-	    setsockopt(0, SOL_SOCKET, SO_KEEPALIVE, &on, sizeof (on)) < 0)
+	    setsockopt(0, SOL_SOCKET, SO_KEEPALIVE, (void *)&on,
+		       sizeof (on)) < 0)
 		syslog(LOG_WARNING, "setsockopt (SO_KEEPALIVE): %m");
 #ifdef IP_TOS
 	on = IPTOS_LOWDELAY;
-	if (setsockopt(0, IPPROTO_IP, IP_TOS, (char *)&on, sizeof(int)) < 0)
+	if (setsockopt(0, IPPROTO_IP, IP_TOS, (void *)&on, sizeof(int)) < 0)
 		syslog(LOG_WARNING, "setsockopt (IP_TOS): %m");
 #endif
 	doit(0, &from);
+	return 0;
 }
 
 int	child;
@@ -341,7 +343,7 @@ void doit(int f, struct sockaddr_in *fromp)
 	int master, pid, on = 1;
 	int authenticated = 0;
 	register struct hostent *hp;
-	char hostname[2 * MAXHOSTNAMELEN + 1];
+	char hostname[2 * MaxHostNameLen + 1];
 	char c;
 
 	alarm(60);
@@ -366,7 +368,7 @@ void doit(int f, struct sockaddr_in *fromp)
 		if (retval == 0)
 			authenticated++;
 		else if (retval > 0)
-			fatal(f, krb_err_txt[retval], 0);
+			fatal(f, krb_get_err_text(retval), 0);
 		write(f, &c, 1);
 		confirmed = 1;		/* we sent the null! */
 	} else
@@ -389,7 +391,7 @@ void doit(int f, struct sockaddr_in *fromp)
 			ipproto = ip->p_proto;
 		else
 			ipproto = IPPROTO_IP;
-		if (getsockopt(0, ipproto, IP_OPTIONS, (char *)optbuf,
+		if (getsockopt(0, ipproto, IP_OPTIONS, (void *)optbuf,
 		    &optsize) == 0 && optsize != 0) {
 			lp = lbuf;
 			for (cp = optbuf; optsize > 0; cp++, optsize--, lp += 3)
@@ -398,7 +400,7 @@ void doit(int f, struct sockaddr_in *fromp)
 			    "Connection received using IP options (ignored):%s",
 			    lbuf);
 			if (setsockopt(0, ipproto, IP_OPTIONS,
-			    (char *)NULL, optsize) != 0) {
+			    (void *)NULL, optsize) != 0) {
 				syslog(LOG_ERR,
 				    "setsockopt IP_OPTIONS NULL: %m");
 				exit(1);
@@ -787,8 +789,7 @@ int do_krb_login(struct sockaddr_in *dest)
 	kdata = (AUTH_DAT *) auth_buf;
 	ticket = (KTEXT) tick_buf;
 
-	instance[0] = '*';
-	instance[1] = '\0';
+	k_getsockinst(0, instance);
 
 	if (doencrypt) {
 		rc = sizeof(faddr);
@@ -843,11 +844,11 @@ void usage(void)
  */
 int local_domain(char *h)
 {
-	char localhost[MAXHOSTNAMELEN];
+	char localhost[MaxHostNameLen];
 	char *p1, *p2;
 
 	localhost[0] = 0;
-	(void) gethostname(localhost, sizeof(localhost));
+	(void) k_gethostname(localhost, sizeof(localhost));
 	p1 = topdomain(localhost);
 	p2 = topdomain(h);
 	if (p1 == NULL || p2 == NULL || !strcasecmp(p1, p2))
