@@ -33,7 +33,7 @@
 
 #include "bsd_locl.h"
 
-RCSID("$Id: rsh.c,v 1.11 1996/02/11 16:06:35 assar Exp $");
+RCSID("$Id: rsh.c,v 1.12 1996/03/24 06:56:47 assar Exp $");
 
 CREDENTIALS cred;
 Key_schedule schedule;
@@ -247,6 +247,7 @@ main(int argc, char **argv)
 	argoff = asrsh = dflag = nflag = nfork = 0;
 	one = 1;
 	host = user = NULL;
+	pid = 0;
 
 	/* if called as something other than "rsh", use it as the host name */
 	if ((p = strrchr(argv[0], '/')))
@@ -367,11 +368,11 @@ try_connect:
 		exit(1);
 	}
 	if (dflag) {
-		if (setsockopt(rem, SOL_SOCKET, SO_DEBUG, &one,
+		if (setsockopt(rem, SOL_SOCKET, SO_DEBUG, (void *)&one,
 		    sizeof(one)) < 0)
 			(void)fprintf(stderr, "rsh: setsockopt: %s.\n",
 			    k_strerror(errno));
-		if (setsockopt(rfd2, SOL_SOCKET, SO_DEBUG, &one,
+		if (setsockopt(rfd2, SOL_SOCKET, SO_DEBUG, (void *)&one,
 		    sizeof(one)) < 0)
 			(void)fprintf(stderr, "rsh: setsockopt: %s.\n",
 			    k_strerror(errno));
