@@ -42,7 +42,7 @@
 
 #include "bsd_locl.h"
 
-RCSID("$Id: rshd.c,v 1.17 1996/02/11 09:05:03 d91-jda Exp $");
+RCSID("$Id: rshd.c,v 1.22 1996/03/24 06:56:48 assar Exp $");
 
 #include <sys/ioctl.h>
 
@@ -134,12 +134,12 @@ main(argc, argv)
 		_exit(1);
 	}
 	if (keepalive &&
-	    setsockopt(0, SOL_SOCKET, SO_KEEPALIVE, (char *)&on,
+	    setsockopt(0, SOL_SOCKET, SO_KEEPALIVE, (void *)&on,
 	    sizeof(on)) < 0)
 		syslog(LOG_WARNING, "setsockopt (SO_KEEPALIVE): %m");
 	linger.l_onoff = 1;
 	linger.l_linger = 60;			/* XXX */
-	if (setsockopt(0, SOL_SOCKET, SO_LINGER, (char *)&linger,
+	if (setsockopt(0, SOL_SOCKET, SO_LINGER, (void *)&linger,
 	    sizeof (linger)) < 0)
 		syslog(LOG_WARNING, "setsockopt (SO_LINGER): %m");
 	doit(&from);
@@ -208,7 +208,7 @@ doit(fromp)
 		ipproto = ip->p_proto;
 	else
 		ipproto = IPPROTO_IP;
-	if (!getsockopt(0, ipproto, IP_OPTIONS, (char *)optbuf, &optsize) &&
+	if (!getsockopt(0, ipproto, IP_OPTIONS, (void *)optbuf, &optsize) &&
 	    optsize != 0) {
 		lp = lbuf;
 		for (cp = optbuf; optsize > 0; cp++, optsize--, lp += 3)
@@ -217,7 +217,7 @@ doit(fromp)
 		    "Connection received from %s using IP options (ignored):%s",
 		    inet_ntoa(fromp->sin_addr), lbuf);
 		if (setsockopt(0, ipproto, IP_OPTIONS,
-		    (char *)NULL, optsize) != 0) {
+		    (void *)NULL, optsize) != 0) {
 			syslog(LOG_ERR, "setsockopt IP_OPTIONS NULL: %m");
 			exit(1);
 		}
@@ -331,7 +331,7 @@ doit(fromp)
 		kdata = (AUTH_DAT *) authbuf;
 		ticket = (KTEXT) tickbuf;
 		authopts = 0L;
-		strcpy(instance, "*");
+		k_getsockinst(0, instance);
 		version[VERSION_SIZE - 1] = '\0';
 		if (doencrypt) {
 			struct sockaddr_in local_addr;
@@ -359,7 +359,7 @@ doit(fromp)
 				kdata, "", (bit_64 *) 0, version);
 		if (rc != KSUCCESS) {
 			error("Kerberos authentication failure: %s\n",
-				  krb_err_txt[rc]);
+				  krb_get_err_text(rc));
 			exit(1);
 		}
 	} else
@@ -596,7 +596,9 @@ fail:
 	(void) setgid((gid_t)pwd->pw_gid);
 	initgroups(pwd->pw_name, pwd->pw_gid);
 	(void) setuid((uid_t)pwd->pw_uid);
+#if 0
 	environ = envinit;
+#endif
 	strncat(homedir, pwd->pw_dir, sizeof(homedir)-6);
 
 	/* Need to extend path to find rcp */
@@ -625,7 +627,7 @@ fail:
 	}
 	if (new_pag && k_hasafs())
 		k_setpag();	/* Put users process in an new pag */
-	execl(pwd->pw_shell, cp, "-c", cmdbuf, 0);
+	execle(pwd->pw_shell, cp, "-c", cmdbuf, 0, envinit);
 	perror(pwd->pw_shell);
 	exit(1);
 }
