@@ -33,12 +33,17 @@
 
 #include "bsd_locl.h"
 
-RCSID("$Id: su.c,v 1.29 1996/02/07 17:29:57 bg Exp $");
+RCSID("$Id: su.c,v 1.35 1996/03/24 06:56:50 assar Exp $");
 
 #ifdef SYSV_SHADOW
 #include "sysv_shadow.h"
 #endif
 
+static int kerberos(char *username, char *user, int uid);
+static int chshell(char *sh);
+static char *ontty();
+static int koktologin(char *name, char *realm, char *toname);
+
 #ifndef HAVE_SETPRIORITY
 int
 setpriority(int which, int who, int niceval)
@@ -103,7 +108,7 @@ main(argc, argv)
 		case '?':
 		default:
 			(void)fprintf(stderr,
-				      "usage: ksu [-Kflm] [-i root-instance] [-] [login]\n");
+				      "usage: su [-Kflm] [-i root-instance] [-] [login]\n");
 			exit(1);
 		}
 	/* Don't handle '-' option with getopt */
@@ -119,7 +124,7 @@ main(argc, argv)
 	if (errno)
 		prio = 0;
 	(void)setpriority(PRIO_PROCESS, 0, -2);
-	openlog("ksu", LOG_CONS, 0);
+	openlog("su", LOG_CONS, 0);
 
 	/* get current login name and shell */
 	ruid = getuid();
@@ -128,7 +133,7 @@ main(argc, argv)
 	    pwd->pw_uid != ruid)
 		pwd = getpwuid(ruid);
 	if (pwd == NULL) {
-		fprintf(stderr, "ksu: who are you?\n");
+		fprintf(stderr, "su: who are you?\n");
 		exit(1);
 	}
 	username = strdup(pwd->pw_name);
@@ -146,19 +151,19 @@ main(argc, argv)
 
 	pwd = getpwnam(user);
 	if (pwd == NULL){
-		fprintf(stderr, "ksu: unknown login %s\n", user);
+		fprintf(stderr, "su: unknown login %s\n", user);
 		exit(1);
 	}
 
 	if (!use_kerberos || kerberos(username, user, pwd->pw_uid)) {
 #ifndef PASSWD_FALLBACK
-	  fprintf(stderr, "ksu: won't use /etc/passwd authentication\n");
+	  fprintf(stderr, "su: won't use /etc/passwd authentication\n");
 	  exit(1);
 #endif
 	  /* getpwnam() is not reentrant and kerberos might use it! */
 	  pwd = getpwnam(user);
 	  if (pwd == NULL){
-		  fprintf(stderr, "ksu: unknown login %s\n", user);
+		  fprintf(stderr, "su: unknown login %s\n", user);
 		  exit(1);
 	  }
 	  /* only allow those in group zero to su to root. */
@@ -173,7 +178,7 @@ main(argc, argv)
 		  break;		/* only root in group 0 */
 #endif
 		fprintf(stderr,
-			"ksu: you are not in the correct group to su %s.\n",
+			"su: you are not in the correct group to su %s.\n",
 			user);
 		exit(1);
 	      }
@@ -196,7 +201,7 @@ main(argc, argv)
 		/* if asme and non-standard target shell, must be root */
 		if (!chshell(pwd->pw_shell) && ruid) {
 			(void)fprintf(stderr,
-				"ksu: permission denied (shell '%s'not in /etc/shells).\n", pwd->pw_shell);
+				"su: permission denied (shell '%s'not in /etc/shells).\n", pwd->pw_shell);
 			exit(1);
 		}
 	} else if (pwd->pw_shell && *pwd->pw_shell) {
@@ -220,16 +225,16 @@ main(argc, argv)
 	
 
 	if (setgid(pwd->pw_gid) < 0) {
-		perror("ksu: setgid");
+		perror("su: setgid");
 		exit(1);
 	}
 	if (initgroups(user, pwd->pw_gid)) {
-		(void)fprintf(stderr, "ksu: initgroups failed.\n");
+		(void)fprintf(stderr, "su: initgroups failed.\n");
 		exit(1);
 	}
 
 	if (setuid(pwd->pw_uid) < 0) {
-		perror("ksu: setuid");
+		perror("su: setuid");
 		exit(1);
 	}
 
@@ -245,7 +250,7 @@ main(argc, argv)
 		  if(k)
 		    setenv("KRBTKFILE", k, 1);
 		  if (chdir(pwd->pw_dir) < 0) {
-		    fprintf(stderr, "ksu: no directory\n");
+		    fprintf(stderr, "su: no directory\n");
 		    exit(1);
 		  }
 		}
@@ -284,27 +289,23 @@ main(argc, argv)
 	if (k_hasafs()) {
 		int code;
 		if (k_setpag() != 0)
-			perror("ksu: setpag");
+			perror("su: setpag");
 		code = k_afsklog(0, 0);
 		if (code != KSUCCESS && code != KDC_PR_UNKNOWN)
-		    fprintf(stderr, "ksu: afsklog: %s\n", krb_err_txt[code]);
+		    fprintf(stderr, "su: afsklog: %s\n", krb_get_err_text(code));
 	}
 
 	execv(shell, np);
-	(void)fprintf(stderr, "ksu: %s not found.\n", shell);
+	(void)fprintf(stderr, "su: %s not found.\n", shell);
 	if (getuid() == 0) {
 		execv(_PATH_BSHELL, np);
-		(void)fprintf(stderr, "ksu: %s not found.\n", _PATH_BSHELL);
+		(void)fprintf(stderr, "su: %s not found.\n", _PATH_BSHELL);
 	}
 	exit(1);
 }
 
-/* this does *not* belong here */
-char *getusershell(void);
-
 static int
-chshell(sh)
-	char *sh;
+chshell(char *sh)
 {
 	register char *cp;
 
@@ -326,10 +327,8 @@ ontty()
 	return (buf);
 }
 
-int
-kerberos(username, user, uid)
-	char *username, *user;
-	int uid;
+static int
+kerberos(char *username, char *user, int uid)
 {
 	KTEXT_ST ticket;
 	AUTH_DAT authdata;
@@ -342,30 +341,14 @@ kerberos(username, user, uid)
 	if (krb_get_lrealm(lrealm, 1) != KSUCCESS)
 		return (1);
 	if (koktologin(username, lrealm, user) && !uid) {
-		(void)fprintf(stderr, "ksu: not in %s's ACL.\n", user);
+		(void)fprintf(stderr, "su: not in %s's ACL.\n", user);
 		return (1);
 	}
-	sprintf(krbtkfile, "%s_%s_to_%s_%d", TKT_ROOT, username, user, getpid());
+	sprintf(krbtkfile, "%s_%s_to_%s_%d", TKT_ROOT, username, user,
+		(int)getpid());
 
 	setenv("KRBTKFILE", krbtkfile, 1);
 	krb_set_tkt_string(krbtkfile);
-	/*
-	 * Set real as well as effective ID to 0 for the moment,
-	 * to make the kerberos library do the right thing.
-	 */
-#if 0
-#if 0
-	if (k_setreuid(uid, 0) < 0) {
-		perror("ksu: setuid");
-		return (1);
-	}
-#else
-	if (setuid(0) < 0) {
-		perror("ksu: setuid");
-		return (1);
-	}
-#endif
-#endif
 	/*
 	 * Little trick here -- if we are su'ing to root,
 	 * we need to get a ticket for "xxx.root", where xxx represents
@@ -393,16 +376,16 @@ kerberos(username, user, uid)
 				(uid == 0 ? root_inst : ""), lrealm);
 			return (1);
 		}
-		(void)fprintf(stderr, "ksu: unable to su: %s\n",
-		    krb_err_txt[kerno]);
+		(void)fprintf(stderr, "su: unable to su: %s\n",
+		    krb_get_err_text(kerno));
 		syslog(LOG_NOTICE|LOG_AUTH,
-		    "BAD KSU: %s to %s%s: %s",
-		    username, user, ontty(), krb_err_txt[kerno]);
+		    "BAD SU: %s to %s%s: %s",
+		    username, user, ontty(), krb_get_err_text(kerno));
 		return (1);
 	}
 
 	if (chown(krbtkfile, uid, -1) < 0) {
-		perror("ksu: chown:");
+		perror("su: chown:");
 		(void)unlink(krbtkfile);
 		return (1);
 	}
@@ -410,7 +393,7 @@ kerberos(username, user, uid)
 	(void)setpriority(PRIO_PROCESS, 0, -2);
 
 	if (gethostname(hostname, sizeof(hostname)) == -1) {
-		perror("ksu: gethostname");
+		perror("su: gethostname");
 		dest_tkt();
 		return (1);
 	}
@@ -424,7 +407,7 @@ kerberos(username, user, uid)
 		(void)fprintf(stderr, "Warning: TGT not verified.\n");
 		syslog(LOG_NOTICE|LOG_AUTH,
 		    "%s to %s%s, TGT not verified (%s); %s.%s not registered?",
-		    username, user, ontty(), krb_err_txt[kerno],
+		    username, user, ontty(), krb_get_err_text(kerno),
 		    "rcmd", savehost);
 #ifdef KLOGIN_PARANOID
 		/*
@@ -437,14 +420,14 @@ kerberos(username, user, uid)
 #endif
 	} else if (kerno != KSUCCESS) {
 		(void)fprintf(stderr, "Unable to use TGT: %s\n",
-		    krb_err_txt[kerno]);
-		syslog(LOG_NOTICE|LOG_AUTH, "failed ksu: %s to %s%s: %s",
-		    username, user, ontty(), krb_err_txt[kerno]);
+		    krb_get_err_text(kerno));
+		syslog(LOG_NOTICE|LOG_AUTH, "failed su: %s to %s%s: %s",
+		    username, user, ontty(), krb_get_err_text(kerno));
 		dest_tkt();
 		return (1);
 	} else {
 		if (!(hp = gethostbyname(hostname))) {
-			(void)fprintf(stderr, "ksu: can't get addr of %s\n",
+			(void)fprintf(stderr, "su: can't get addr of %s\n",
 			    hostname);
 			dest_tkt();
 			return (1);
@@ -454,11 +437,11 @@ kerberos(username, user, uid)
 		if ((kerno = krb_rd_req(&ticket, "rcmd", savehost, faddr,
 		    &authdata, "")) != KSUCCESS) {
 			(void)fprintf(stderr,
-			    "ksu: unable to verify rcmd ticket: %s\n",
-			    krb_err_txt[kerno]);
+			    "su: unable to verify rcmd ticket: %s\n",
+			    krb_get_err_text(kerno));
 			syslog(LOG_NOTICE|LOG_AUTH,
-			    "failed ksu: %s to %s%s: %s", username,
-			     user, ontty(), krb_err_txt[kerno]);
+			    "failed su: %s to %s%s: %s", username,
+			     user, ontty(), krb_get_err_text(kerno));
 			dest_tkt();
 			return (1);
 		}
@@ -467,7 +450,7 @@ kerberos(username, user, uid)
 	return (0);
 }
 
-int
+static int
 koktologin(char *name, char *realm, char *toname)
 {
 	register AUTH_DAT *kdata;
