@@ -2,7 +2,7 @@
 
 #include "bsd_locl.h"
 
-RCSID("$Id: sysv_default.c,v 1.6 1996/01/09 22:54:54 bg Exp $");
+RCSID("$Id: sysv_default.c,v 1.7 1996/03/10 15:11:46 assar Exp $");
 
 #include "sysv_default.h"
 
@@ -31,19 +31,19 @@ static struct sysv_default {
     char   *prefix;
     int     prefix_len;
 } defaults[] = {
-    &default_console,	"CONSOLE=",	sizeof("CONSOLE=") -1,
-    &default_altsh,	"ALTSHELL=",	sizeof("ALTSHELL=") -1,
-    &default_passreq,	"PASSREQ=",	sizeof("PASSREQ=") -1,
-    &default_timezone,	"TIMEZONE=",	sizeof("TIMEZONE=") -1,
-    &default_hz,	"HZ=",		sizeof("HZ=") -1,
-    &default_path,	"PATH=",	sizeof("PATH=") -1,
-    &default_supath,	"SUPATH=",	sizeof("SUPATH=") -1,
-    &default_ulimit,	"ULIMIT=",	sizeof("ULIMIT=") -1,
-    &default_timeout,	"TIMEOUT=",	sizeof("TIMEOUT=") -1,
-    &default_umask,	"UMASK=",	sizeof("UMASK=") -1,
-    &default_sleep,	"SLEEPTIME=",	sizeof("SLEEPTIME=") -1,
-    &default_maxtrys,	"MAXTRYS=",	sizeof("MAXTRYS=") -1,
-    0,
+    {&default_console,	"CONSOLE=",	sizeof("CONSOLE=") -1},
+    {&default_altsh,	"ALTSHELL=",	sizeof("ALTSHELL=") -1},
+    {&default_passreq,	"PASSREQ=",	sizeof("PASSREQ=") -1},
+    {&default_timezone,	"TIMEZONE=",	sizeof("TIMEZONE=") -1},
+    {&default_hz,	"HZ=",		sizeof("HZ=") -1},
+    {&default_path,	"PATH=",	sizeof("PATH=") -1},
+    {&default_supath,	"SUPATH=",	sizeof("SUPATH=") -1},
+    {&default_ulimit,	"ULIMIT=",	sizeof("ULIMIT=") -1},
+    {&default_timeout,	"TIMEOUT=",	sizeof("TIMEOUT=") -1},
+    {&default_umask,	"UMASK=",	sizeof("UMASK=") -1},
+    {&default_sleep,	"SLEEPTIME=",	sizeof("SLEEPTIME=") -1},
+    {&default_maxtrys,	"MAXTRYS=",	sizeof("MAXTRYS=") -1},
+    {0},
 };
 
 #define trim(s) { \
@@ -55,6 +55,7 @@ static struct sysv_default {
 
 /* sysv_defaults - read login defaults file */
 
+void
 sysv_defaults()
 {
     struct sysv_default *dp;
