@@ -2,7 +2,7 @@
 
 #include "bsd_locl.h"
 
-RCSID("$Id: sysv_environ.c,v 1.9 1996/02/10 20:01:48 assar Exp $");
+RCSID("$Id: sysv_environ.c,v 1.11 1996/03/20 02:09:12 assar Exp $");
 
 #ifdef SYSV_ENV
 
@@ -56,9 +56,9 @@ static struct preserved {
     char   *name;
     char   *value;
 } preserved[] = {
-    "TZ", 0,
-    "TERM", 0,
-    0,
+    {"TZ", 0},
+    {"TERM", 0},
+    {0},
 };
 
  /*
@@ -73,28 +73,22 @@ static struct censored {
     char   *prefix;
     int     length;
 } censored[] = {
-    "SHELL=",	sizeof("SHELL=") - 1,
-    "HOME=",	sizeof("HOME=") - 1,
-    "LOGNAME=",	sizeof("LOGNAME=") - 1,
-    "MAIL=",	sizeof("MAIL=") - 1,
-    "CDPATH=",	sizeof("CDPATH=") - 1,
-    "IFS=",	sizeof("IFS=") - 1,
-    "PATH=",	sizeof("PATH=") - 1,
-    "LD_",	sizeof("LD_") - 1,
-    0,
+  {"SHELL=",	sizeof("SHELL=") - 1},
+     {"HOME=",	sizeof("HOME=") - 1},
+     {"LOGNAME=",	sizeof("LOGNAME=") - 1},
+     {"MAIL=",	sizeof("MAIL=") - 1},
+     {"CDPATH=",	sizeof("CDPATH=") - 1},
+     {"IFS=",	sizeof("IFS=") - 1},
+     {"PATH=",	sizeof("PATH=") - 1},
+    {"LD_",	sizeof("LD_") - 1},
+    {0},
 };
 
 /* sysv_newenv - set up final environment after logging in */
 
-sysv_newenv(argc, argv, pwd, term, pflag)
-int     argc;
-char  **argv;
-struct passwd *pwd;
-char   *term;
-int pflag;
+void sysv_newenv(int argc, char **argv, struct passwd *pwd,
+		 char *term, int pflag)
 {
-    char   *env_tz;
-    char   *env_term;
     unsigned umask_val;
     long    limit_val;
     char    buf[BUFSIZ];
@@ -159,7 +153,7 @@ int pflag;
     /* Undocumented: HOME, MAIL and LOGNAME are always reset (SunOS 5.1). */
 
     setenv("HOME", pwd->pw_dir, 1);
-    sprintf(buf, "%s/%s", _PATH_MAILDIR, pwd->pw_name);
+    sprintf(buf, "%s/%s", KRB4_MAILDIR, pwd->pw_name);
     setenv("MAIL", buf, 1);
     setenv("LOGNAME", pwd->pw_name, 1);
 #ifdef ENV_USER
