@@ -8,7 +8,7 @@
 #define DAY_NOW (time_t)time((time_t *)0) / DAY
 #endif /* DAY_NOW */
 
-struct spwd *spwd;
+static struct spwd *spwd;
 
 static struct passwd *fix_getpwnam(u)
 char   *u;
