@@ -6,45 +6,26 @@
  * new PAG and when the command exits the tickets are destroyed.
  */
 
-#include "config.h"
+#include "kauth.h"
 
-RCSID("$Header: /afs/nada.kth.se/src/packages/kth-krb/SourceRepository/krb4/appl/kauth/kauth.c,v 1.40 1996/02/09 23:29:12 assar Exp $");
-
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
-#include <signal.h>
-#include <errno.h>
-
-#include <pwd.h>
-#include <unistd.h>
-#ifdef HAVE_SYS_TIME_H
-#include <sys/time.h>
-#endif
-#ifdef HAVE_SYS_RESOURCE_H
-#include <sys/resource.h>
-#endif /* HAVE_SYS_RESOURCE_H */
-#include <sys/wait.h>
-
-#include <krb.h>
-#include <kafs.h>
-
-extern char *optarg;
-extern int optind, opterr;
-extern char *getenv();
+RCSID("$Header: /src/packages/kth-krb/SourceRepository/krb4/appl/kauth/kauth.c,v 1.47 1996/03/24 23:42:41 d91-jda Exp $");
 
 char *prog;
-char inst[100];
-char name[100];
-char realm[REALM_SZ + 1];
-char srvtab[MaxPathLen + 1];
-int lifetime = DEFAULT_TKT_LIFE;
+static char inst[100];
+static char name[100];
+static char realm[REALM_SZ + 1];
+static char srvtab[MaxPathLen + 1];
+static int lifetime = DEFAULT_TKT_LIFE;
+static char remote_tktfile[MaxPathLen + 1];
+static char remoteuser[100];
 
 static void
 usage()
 {
   fprintf(stderr,
-	  "Usage: %s -n <name> [ -l lifetime (in minutes) ] [ -f srvtab ] [ -c AFS cell name ] [ command ... ]\n",
+	  "Usage: %s [-n <name>] [-r remoteuser] [-t remote ticketfile]"
+	  "[ -l lifetime (in minutes) ] [ -h hosts... ]"
+	  "[ -f srvtab ] [ -c AFS cell name ] [ command ... ]\n",
 	  prog);
   fprintf(stderr, "\nA fully qualified name can be given user[.instance][@realm]\nRealm is converted to uppercase!\n");
   exit(1);
@@ -92,11 +73,11 @@ renew(int sig)
   code = krb_get_svc_in_tkt(name, inst, realm,
 			    "krbtgt", realm, lifetime, srvtab);
   if (code)
-    fprintf(stderr, "%s: %s\n", prog, krb_err_txt[code]);
+    fprintf(stderr, "%s: %s\n", prog, krb_get_err_text(code));
   else if (k_hasafs())
     {
       if ((code = k_afsklog(0, realm)) != 0 && code != KDC_PR_UNKNOWN) {
-        fprintf(stderr, "%s: %s\n", prog, krb_err_txt[code]);
+        fprintf(stderr, "%s: %s\n", prog, krb_get_err_text(code));
       }
     }
 
@@ -130,13 +111,19 @@ zrefresh()
   return 0;
 }
 
-static
-void
+static void
 upcase(char *t)
 {
     for (; *t; t++)
-	if ('a' <= *t && *t <= 'z')
-	    *t = *t - 'a' + 'A';
+        *t = toupper(*t);
+}
+
+static int
+key_to_key(char *user, char *instance, char *realm, void *arg,
+	   des_cblock *key)
+{
+  memcpy(key, arg, sizeof(des_cblock));
+  return 0;
 }
 
 int
@@ -145,9 +132,15 @@ main(argc, argv)
      char **argv;
 {
   int code, more_args;
+  int ret;
   int c;
   char *cell = 0;
   char *file;
+  int pflag = 0;
+  char passwd[100];
+  des_cblock key;
+  char **host;
+  int nhost;
 
   if ((file =  getenv("KRBTKFILE")) == 0)
     file = TKT_FILE;  
@@ -157,21 +150,20 @@ main(argc, argv)
   memset(name, 0, sizeof(name));
   memset(realm, 0, sizeof(realm));
   memset(srvtab, 0, sizeof(srvtab));
+  *remoteuser = '\0';
+  nhost = 0;
   
-  /* Look for kerberos name */
-  if (argc > 1 &&
-      argv[1][0] != '-' &&
-      kname_parse(name, inst, realm, argv[1]) == 0)
-    {
-      argc--, argv++;
-      upcase(realm);
-    }
-
-  while ((c = getopt(argc, argv, "f:hl:n:c:")) != EOF)
+  while ((c = getopt(argc, argv, "r:t:f:hl:n:c:")) != EOF)
     switch (c) {
     case 'f':
       strncpy(srvtab, optarg, sizeof(srvtab));
       break;
+    case 't':
+      strncpy(remote_tktfile, optarg, sizeof(remote_tktfile));
+      break;
+    case 'r':
+      strncpy(remoteuser, optarg, sizeof(remoteuser));
+      break;
     case 'l':
       lifetime = atoi(optarg);
       if (lifetime == -1)
@@ -186,24 +178,37 @@ main(argc, argv)
     case 'n':
       if ((code = kname_parse(name, inst, realm, optarg)) != 0)
 	{
-	  fprintf(stderr, "%s\n", krb_err_txt[code]);
+	  fprintf(stderr, "%s\n", krb_get_err_text(code));
 	  usage();
 	}
       upcase(realm);
+      pflag = 1;
       break;
     case 'c':
       cell = optarg;
       break;
     case 'h':
+      host = argv + optind;
+      for(nhost = 0; optind < argc && *argv[optind] != '-'; ++optind)
+	++nhost;
+      break;
     case '?':
       usage();
       break;
     default:
-      fprintf(stderr, "Unknown option, try -h\n");
+      fprintf(stderr, "Unknown option, try -?\n");
       exit(1);
       break;
     }
   
+  /* Look for kerberos name */
+  if (!pflag && optind < argc &&
+      kname_parse(name, inst, realm, argv[optind]) == 0)
+    {
+      ++optind;	 
+      upcase(realm);
+    }
+
   /* No kerberos name, look for old ticket file. */
   if (name[0] == 0 && tf_init(file, R_TKT_FIL) == KSUCCESS)
     {
@@ -217,7 +222,7 @@ main(argc, argv)
 	{
 	  fprintf(stderr,
 		  "failed to read %s: %s. Ignoring %s and continuing\n",
-		  file, krb_err_txt[code], file);
+		  file, krb_get_err_text(code), file);
 	  name[0] = 0;
 	}
     }
@@ -239,6 +244,9 @@ main(argc, argv)
 	}
     }
   
+  if (*remoteuser == '\0')
+    strcpy (remoteuser, name);
+
   more_args = argc - optind;
 
   if (realm[0] == 0)
@@ -248,20 +256,35 @@ main(argc, argv)
   if (srvtab[0])
     {
       signal(SIGALRM, renew);
+
+
+      code = read_service_key (name, inst, realm, 0, srvtab, &key);
+      if (code == KSUCCESS)
+	code = krb_get_in_tkt(name, inst, realm, "krbtgt", realm, lifetime,
+			      key_to_key, NULL, key);
       alarm(krb_life_to_time(0, lifetime)/2 - 60);
-      code = krb_get_svc_in_tkt(name, inst, realm,
-				"krbtgt", realm, lifetime, srvtab);
     }
   else
     {
       printf("User's %s%s%s@%s ", name, inst[0] ? "." : "", inst, realm);
       fflush(stdout);
-      code = krb_get_pw_in_tkt(name, inst, realm,
-			       "krbtgt", realm, lifetime, 0);
+      if (des_read_pw_string(passwd, sizeof(passwd)-1, "Password: ", 0))
+	*passwd = '\0';
+      des_string_to_key (passwd, &key);
+      code = krb_get_in_tkt (name, inst, realm, "krbtgt", realm, lifetime,
+			     key_to_key, NULL, key);
+      if(code == INTK_BADPW)
+	{
+	  afs_string_to_key (passwd, realm, &key);
+	  code = krb_get_in_tkt (name, inst, realm, "krbtgt", realm, lifetime,
+				 key_to_key, NULL, key);
+	}
+      memset(passwd, 0, sizeof(passwd));
     }
   if (code)
     {
-      fprintf(stderr, "%s\n", krb_err_txt[code]);
+      memset (key, 0, sizeof(key));
+      fprintf(stderr, "%s\n", krb_get_err_text(code));
       exit(1);
     }
 
@@ -270,13 +293,20 @@ main(argc, argv)
       if (more_args)
         k_setpag();
       if ((code = k_afsklog(cell, realm)) != 0 && code != KDC_PR_UNKNOWN)
-        fprintf(stderr, "%s: %s\n", prog, krb_err_txt[code]);
+        fprintf(stderr, "%s: %s\n", prog, krb_get_err_text(code));
     }
 
+  for(ret = 0; nhost-- > 0; host++)
+    ret += rkinit(name, inst, realm, lifetime, remoteuser,
+		  remote_tktfile, &key, *host);
+
+  if (ret)
+    return ret;
+
   if (more_args)
     doexec(more_args, &argv[optind]);
   else
     zrefresh();
 
-  exit(0);
+  return 0;
 }
