@@ -9,16 +9,7 @@ static char copyright[] = "Copyright (c) 1990 Regents of the University of Calif
 static char SccsId[] = "@(#)@(#)pop_dropcopy.c	2.6  2.6 4/3/91";
 #endif /* not lint */
 
-#include <errno.h>
-#include <stdio.h>
-#include <sys/types.h>
-#include <unistd.h>
-#include <string.h>
-#include <sys/stat.h>
-#include <sys/file.h>
-#include <fcntl.h>
-#include <pwd.h>
-#include "popper.h"
+#include <popper.h>
 
 extern int      errno;
 
@@ -27,9 +18,8 @@ extern int      errno;
  *  save a stream pointer for it.
  */
 
-pop_dropcopy(p,pwp)
-POP     *   p;
-struct passwd	*	pwp;
+int
+pop_dropcopy(POP *p, struct passwd *pwp)
 {
     int                     mfd;                    /*  File descriptor for 
                                                         the user's maildrop */
@@ -40,7 +30,6 @@ struct passwd	*	pwp;
     char                    buffer[BUFSIZ];         /*  Read buffer */
     long                    offset;                 /*  Old/New boundary */
     int                     nchar;                  /*  Bytes written/read */
-    struct stat             mybuf;                  /*  For lstat() */
 
     /*  Create a temporary maildrop into which to copy the updated maildrop */
     (void)sprintf(p->temp_drop,POP_DROP,p->user);
