@@ -9,10 +9,7 @@ static char copyright[] = "Copyright (c) 1990 Regents of the University of Calif
 static char SccsId[] = "@(#)@(#)pop_log.c	2.1  2.1 3/18/91";
 #endif /* not lint */
 
-#include <stdio.h>
-#include <sys/types.h>
-#include <stdarg.h>
-#include "popper.h"
+#include <popper.h>
 
 /* 
  *  log:    Make a log entry
@@ -24,8 +21,8 @@ int
 pop_log(POP *p, int stat, char *format, ...)
 {
     va_list     ap;
-    va_start(ap, format);
 
+    va_start(ap, format);
 #ifdef HAVE_VSPRINTF
         vsprintf(msgbuf,format,ap);
 #else
