@@ -9,16 +9,14 @@ static char copyright[] = "Copyright (c) 1990 Regents of the University of Calif
 static char SccsId[] = "@(#)@(#)pop_rset.c	2.1  2.1 3/18/91";
 #endif /* not lint */
 
-#include <stdio.h>
-#include <sys/types.h>
-#include "popper.h"
+#include <popper.h>
 
 /* 
  *  rset:   Unflag all messages flagged for deletion in a POP maildrop
  */
 
-int pop_rset (p)
-POP     *   p;
+int
+pop_rset (POP *p)
 {
     MsgInfoList     *   mp;         /*  Pointer to the message info list */
     register int        i;
