@@ -9,22 +9,17 @@ static char copyright[] = "Copyright (c) 1990 Regents of the University of Calif
 static char SccsId[] = "@(#)@(#)pop_user.c	2.1  2.1 3/18/91";
 #endif /* not lint */
 
-#include <stdio.h>
-#include <sys/types.h>
-#include <string.h>
-#include "popper.h"
+#include <popper.h>
 
 /* 
  *  user:   Prompt for the user name at the start of a POP session
  */
 
-int pop_user (p)
-POP     *   p;
+int
+pop_user (POP *p)
 {
-#ifndef KERBEROS
     /*  Save the user name */
     (void)strcpy(p->user, p->pop_parm[1]);
-#endif /* KERBEROS */
 
     /*  Tell the user that the password is required */
     return (pop_msg(p,POP_SUCCESS,"Password required for %s.",p->user));
