@@ -53,7 +53,7 @@
 
 #include <config.h>
 
-RCSID("$Id: kerberos.c,v 1.5 1996/02/11 05:24:05 d91-jda Exp $");
+RCSID("$Id: kerberos.c,v 1.8 1996/03/11 09:21:51 bg Exp $");
 
 #ifdef	KRB4
 #include <sys/types.h>
@@ -194,11 +194,11 @@ kerberos4_send(char *name, Authenticator *ap)
 		return(0);
 	}
 	if (r = krb_mk_req(&auth, KRB_SERVICE_NAME, instance, realm, 0L)) {
-		printf("mk_req failed: %s\r\n", krb_err_txt[r]);
+		printf("mk_req failed: %s\r\n", krb_get_err_text(r));
 		return(0);
 	}
 	if (r = krb_get_cred(KRB_SERVICE_NAME, instance, realm, &cred)) {
-		printf("get_cred failed: %s\r\n", krb_err_txt[r]);
+		printf("get_cred failed: %s\r\n", krb_get_err_text(r));
 		return(0);
 	}
 	if (!auth_sendname(UserNameRequested, strlen(UserNameRequested))) {
@@ -293,12 +293,12 @@ kerberos4_is(ap, data, cnt)
 			printd(auth.dat, auth.length);
 			printf("\r\n");
 		}
-		instance[0] = '*'; instance[1] = 0;
+		k_getsockinst(0, instance); /* Telnetd uses socket 0 */
 		if (r = krb_rd_req(&auth, KRB_SERVICE_NAME,
 				   instance, 0, &adat, "")) {
 			if (auth_debug_mode)
 				printf("Kerberos failed him as %s\r\n", name);
-			Data(ap, KRB_REJECT, (void *)krb_err_txt[r], -1);
+			Data(ap, KRB_REJECT, (void *)krb_get_err_text(r), -1);
 			auth_finished(ap, AUTH_REJECT);
 			return;
 		}
