@@ -1,5 +1,5 @@
 /*
- *	$Source: /afs/nada.kth.se/src/packages/kth-krb/SourceRepository/krb4/appl/telnet/libtelnet/kerberos5.c,v $
+ *	$Source: /src/packages/kth-krb/SourceRepository/krb4/appl/telnet/libtelnet/kerberos5.c,v $
  *	$Author: bg $
  *	$Id: kerberos5.c,v 1.4 1995/12/27 13:24:51 bg Exp $
  */
