@@ -33,7 +33,7 @@
 
 #include <config.h>
 
-RCSID("$Id: utilities.c,v 1.5 1996/02/04 14:41:51 d91-jda Exp $");
+RCSID("$Id: utilities.c,v 1.6 1996/03/24 06:57:27 assar Exp $");
 
 #define	TELOPTS
 #define	TELCMDS
@@ -92,7 +92,7 @@ SetSockOpt(fd, level, option, yesno)
 {
 #ifndef	NOT43
     return setsockopt(fd, level, option,
-				(char *)&yesno, sizeof yesno);
+				(void *)&yesno, sizeof yesno);
 #else	/* NOT43 */
     if (yesno == 0) {		/* Can't do that in 4.2! */
 	fprintf(stderr, "Error: attempt to turn off an option 0x%x.\n",
