@@ -33,7 +33,7 @@
 
 #include <config.h>
 
-RCSID("$Id: sys_term.c,v 1.33 1996/02/11 23:21:10 d91-jda Exp $");
+RCSID("$Id: sys_term.c,v 1.34 1996/02/26 16:58:28 d91-jda Exp $");
 
 #include "telnetd.h"
 #include "pathnames.h"
@@ -1564,6 +1564,14 @@ void start_login(char *host, int autologin, char *name)
 	if (auth_level < 0 || autologin != AUTH_VALID) {
 		printf("User not authenticated. "
 		       "Using plaintext username and password\r\n");
+		if(log_unauth) {
+		  char *u;
+		  if(name[0]) u = name;
+		  else u=getenv("USER");
+		  u = u ? u : "unknown user";
+		  syslog(LOG_INFO, "unauthenticated access from %s (%s)", 
+			 host, u);
+		}
 	}
 	if (auth_level >= 0 && autologin == AUTH_VALID) {
 # if	!defined(NO_LOGIN_F)
