@@ -9,12 +9,12 @@
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #include <protos.h>
-#define KERBEROS
-RCSID("$Id: xnlock.c,v 1.18 1996/02/11 12:28:36 bg Exp $");
+RCSID("$Id: xnlock.c,v 1.26 1996/03/24 06:57:35 assar Exp $");
 #endif
 
 #include <stdio.h>
 #include <stdlib.h>
+#include <string.h>
 #include <signal.h>
 #include <X11/StringDefs.h>
 #include <X11/Intrinsic.h>
@@ -23,28 +23,31 @@ RCSID("$Id: xnlock.c,v 1.18 1996/02/11 12:28:36 bg Exp $");
 #include <X11/Xos.h>
 #include <ctype.h>
 #include <pwd.h>
-#include <xnlock.h>
 
-#ifdef KERBEROS
 #include <krb.h>
 #include <kafs.h>
 
+char *crypt(const char *, const char *);
+
 char inst[100];
 char name[100];
 char realm[REALM_SZ + 1];
-#endif
+
+#define font_height(font)	  	(font->ascent + font->descent)
 
 char *SPACE_STRING = "                                                      ";
 char STRING[] = "****************";
+
 #define MAX_PASSWD_LENGTH (sizeof(STRING))
 
 /* The program should be something that outputs a small amount of text */
 #define DEFAULT_PROGRAM "fortune -s"
 #define DEFAULT_TEXT    "I'm out running around."
-#define font_height(font)	  	(font->ascent + font->descent)
 #define FONT_NAME	"-*-new century schoolbook-*-*-*-18-*"
-#define when 		break;case
-#define otherwise 	break;default
+
+#ifndef MAXPATHLEN
+#define MAXPATHLEN BUFSIZ
+#endif /* MAXPATHLEN */
 
 #define PROMPT	    "Password: "
 #define FAIL_MSG    "Sorry, try again"
@@ -55,8 +58,8 @@ char STRING[] = "****************";
 #define FRONT	020
 #define X_INCR 3
 #define Y_INCR 2
-#define CTRL 1
-#define NOCTRL 1
+#define XNLOCK_CTRL 1
+#define XNLOCK_NOCTRL 0
 
 XtAppContext	app;
 Display        *dpy;
@@ -258,7 +261,9 @@ zrefresh()
       /* Child */
       execlp("zrefresh", "zrefresh", 0);
       execl("/usr/athena/bin/zrefresh", "zrefresh", 0);
+#if 0
       fprintf(stderr, "Warning %s: Failed to exec zrefresh\n", ProgName);
+#endif
       return -1;
   default:
       /* Parent */
@@ -432,14 +437,10 @@ post_prompt_box(Window window)
     box_x = prompt_x - 105;
     box_y = prompt_y - 3 * font_height(font);
 
-#ifdef KERBEROS
     if (inst[0] == 0)
 	sprintf (s, "User: %s@%s", name, realm);
     else
 	sprintf (s, "User: %s.%s@%s", name, inst, realm);
-#else
-    sprintf (s, "User: %s", pw->pw_name);
-#endif
     /* erase current guy -- text message may still exist */
     XSetForeground(dpy, gc, Black);
     XFillRectangle(dpy, window, gc, x, y, 64, 64);
@@ -466,6 +467,17 @@ post_prompt_box(Window window)
     time_y += 2*font_height(font);
 }
 
+static void
+RaiseWindow(Widget w, XEvent *ev, String *s, Cardinal *n)
+{
+  Widget x;
+  if(!XtIsRealized(w))
+    return;
+  x = XtParent(w);
+  XRaiseWindow(dpy, XtWindow(x));
+}
+
+
 static void
 ClearWindow(Widget w, XEvent *_event, String *_s, Cardinal *_n)
 {
@@ -489,12 +501,6 @@ ClearWindow(Widget w, XEvent *_event, String *_s, Cardinal *_n)
     }
 }
 
-static void
-Visibility(Widget w, XtPointer client_data, XEvent *event, Boolean *_b)
-{
-    XRaiseWindow(dpy, XtWindow(w));
-}
-
 static void
 countdown(XtPointer _t, XtIntervalId *_d)
 {
@@ -532,7 +538,7 @@ GetPasswd(Widget w, XEvent *_event, String *_s, Cardinal *_n)
     XKeyEvent *event = (XKeyEvent *)_event;
     static char passwd[MAX_PASSWD_LENGTH];
     static int cnt;
-    static int is_ctrl = NOCTRL;
+    static int is_ctrl = XNLOCK_NOCTRL;
     char c;
     KeySym keysym;
 
@@ -555,14 +561,14 @@ GetPasswd(Widget w, XEvent *_event, String *_s, Cardinal *_n)
     if (event->type == KeyRelease) {
       keysym = XLookupKeysym(event, 0);
       if (keysym == XK_Control_L || keysym == XK_Control_R) {
-	is_ctrl = NOCTRL;
+	is_ctrl = XNLOCK_NOCTRL;
       }
     }
     if (event->type != KeyPress)
 	return;
     keysym = XLookupKeysym(event, 0);
     if (keysym == XK_Control_L || keysym == XK_Control_R) {
-      is_ctrl = CTRL;
+      is_ctrl = XNLOCK_CTRL;
       return;
     }
     if (!XLookupString(event, &c, 1, &keysym, 0))
@@ -592,7 +598,6 @@ GetPasswd(Widget w, XEvent *_event, String *_s, Cardinal *_n)
 		 * continue */
 		signal(SIGHUP, SIG_DFL);
 	    }
-#ifdef KERBEROS
 	/*
 	 * Try to verify as user with kerberos.
 	 */
@@ -614,12 +619,11 @@ GetPasswd(Widget w, XEvent *_event, String *_s, Cardinal *_n)
 				    fprintf(stderr,
 					    "%s: Warning %s\n",
 					    ProgName,
-					    krb_err_txt[code]);
+					    krb_get_err_text(code));
 			    }
 			leave();
 		    }
 	    }
-#endif /* KERBEROS */
 	/*
 	 * Try to verify as user.
 	 */
@@ -636,7 +640,7 @@ GetPasswd(Widget w, XEvent *_event, String *_s, Cardinal *_n)
     if (keysym == XK_BackSpace || keysym == XK_Delete || keysym == XK_Left) {
 	if (cnt)
 	    passwd[cnt--] = ' ';
-    } else if (keysym == XK_u && is_ctrl == 1) {
+    } else if (keysym == XK_u && is_ctrl == XNLOCK_CTRL) {
       while (cnt) {
 	passwd[cnt--] = ' ';
 	XDrawImageString(dpy, XtWindow(w), gc,
@@ -851,13 +855,16 @@ main (int argc, char **argv)
 	ProgName = *argv;
 
     /* getpwuid() returns static pointer, so get root's passwd first */
-    if (!(pw = getpwuid(0)))
-	printf("%s: can't get root's passwd!\n", ProgName), exit(1);
+    if (!(pw = getpwuid(0))){
+	fprintf(stderr, "%s: can't get root's passwd!\n", ProgName);
+	exit(1);
+    }
     strcpy(root_pw, pw->pw_passwd);
-    if (!(pw = getpwuid(getuid())))
-	printf("%s: Intruder alert!\n", ProgName), exit(1);
+    if (!(pw = getpwuid(getuid()))){
+      fprintf(stderr, "%s: Can't get your password entry!\n", ProgName);
+      exit(1);
+    } 
 
-#ifdef KERBEROS
     {
 	int code = KSUCCESS;
 	char *file;
@@ -874,8 +881,6 @@ main (int argc, char **argv)
 		    (code = tf_get_pinst(inst)) == KSUCCESS)
 		    {
 			(void) tf_close(); /* Alles gut */
-			dest_tkt(); /* Nuke old ticket file */
-			creat(file, 0600); /* but keep a place holder */
 		    }
 	    }
 	if (code != KSUCCESS)
@@ -885,7 +890,6 @@ main (int argc, char **argv)
 		    realm[0] = 0; /* No kerberos today */
 	    }
     }
-#endif /* KERBEROS */
     
     XtToolkitInitialize();
     app = XtCreateApplicationContext();
@@ -901,12 +905,14 @@ main (int argc, char **argv)
     Width = DisplayWidth(dpy, DefaultScreen(dpy)) + 2;
     Height = DisplayHeight(dpy, DefaultScreen(dpy)) + 2;
     override = XtVaAppCreateShell("xnlock", "XNlock",
-	overrideShellWidgetClass, dpy, XtNx, -1, XtNy, -1, NULL);
+				  overrideShellWidgetClass, dpy, 
+				  XtNx, -1, 
+				  XtNy, -1, 
+				  NULL);
+
     XtGetApplicationResources(override, &Resrcs,
 	resources, XtNumber(resources), NULL, 0);
 
-    XtAddEventHandler(override, VisibilityChangeMask, FALSE, Visibility, NULL);
-
     widget = XtVaCreateManagedWidget("_foo", widgetClass, override,
 	XtNwidth,	Width,
 	XtNheight,	Height,
@@ -950,13 +956,16 @@ main (int argc, char **argv)
 	static XtActionsRec actions[] = {
 	    { "ClearWindow",	ClearWindow  },
 	    { "GetPasswd",	GetPasswd    },
+	    { "RaiseWindow", 	RaiseWindow  },
 	};
 	XtAppAddActions(app, actions, XtNumber(actions));
 	XtOverrideTranslations(widget,
-	    XtParseTranslationTable(
-		"<Expose>:	ClearWindow()	\n\
-		 <BtnDown>:	GetPasswd()	\n\
-		 <KeyPress>:	GetPasswd()"));
+	       XtParseTranslationTable(
+				       "<Expose>:	ClearWindow()	\n"
+				       "<BtnDown>:	GetPasswd()	\n"
+				       "<Visible>: RaiseWindow() \n"
+				       "<KeyRelease>:  GetPasswd()     \n"
+				       "<KeyPress>:	GetPasswd()"));
     }
 
     XtRealizeWidget(override);
