@@ -3,7 +3,7 @@
  *
  * $Locker:  $
  *
- * $Header: /afs/nada.kth.se/src/packages/kth-krb/SourceRepository/krb4/include/protos.h,v 1.12 1996/02/09 23:29:35 assar Exp $
+ * $Header: /src/packages/kth-krb/SourceRepository/krb4/include/protos.h,v 1.13 1996/03/24 06:57:39 assar Exp $
  *
  */
 
@@ -65,7 +65,7 @@ int sendto(int, const char *, int, int, void *, int);
 int select(int, fd_set *, fd_set *, fd_set *, struct timeval *);
 int shutdown(int, int);
 int getpeername(int, struct sockaddr *, int *);
-int getsockopt(int, int, int, char *, int *);
+int getsockopt(int, int, int, void *, int *);
 int send(int s, const void *msg, int len, int flags);
 
 char *inet_ntoa(struct in_addr in);
