@@ -35,7 +35,7 @@ or implied warranty.
 
 #include "kadm_locl.h"
 
-RCSID("$Header: /afs/nada.kth.se/src/packages/kth-krb/SourceRepository/krb4/kadmin/admin_server.c,v 1.21 1996/02/07 10:48:14 d91-jda Exp $");
+RCSID("$Header: /src/packages/kth-krb/SourceRepository/krb4/kadmin/admin_server.c,v 1.22 1996/03/24 06:57:41 assar Exp $");
 
 /* Almost all procs and such need this, so it is global */
 admin_params prm;		/* The command line parameters struct */
@@ -163,7 +163,7 @@ process_client(int fd, struct sockaddr_in *who)
     int more;
     int status;
 
-    if (setsockopt(fd, SOL_SOCKET, SO_KEEPALIVE, &on, sizeof(on)) < 0)
+    if (setsockopt(fd, SOL_SOCKET, SO_KEEPALIVE, (void *)&on, sizeof(on)) < 0)
 	k_log("setsockopt keepalive: %d",errno);
 
     server_parm.recv_addr = *who;
@@ -290,7 +290,8 @@ kadm_listen(void)
 	return KADM_NO_SOCK;
     {
       int one=1;
-      setsockopt(admin_fd, SOL_SOCKET, SO_REUSEADDR, &one, sizeof(one));
+      setsockopt(admin_fd, SOL_SOCKET, SO_REUSEADDR, (void *)&one,
+		 sizeof(one));
     }
     if (bind(admin_fd, (struct sockaddr *)&server_parm.admin_addr,
 	     sizeof(struct sockaddr_in)) < 0)
