@@ -78,6 +78,8 @@ int kadm_ser_get __P((u_char *, int, AUTH_DAT *, u_char **, int *));
 int kadm_ser_init __P((int inter, char realm[]));
 int kadm_ser_in __P((u_char **, int *));
 
+int get_pw_new_pwd(char *pword, int pwlen, char *name, char *inst,
+		    char *realm, int print_realm);
 
 long maketime __P((struct tm *, int));
 
