@@ -30,7 +30,7 @@ or implied warranty.
 
 #include "kadm_locl.h"
 
-RCSID("$Header: /afs/nada.kth.se/src/packages/kth-krb/SourceRepository/krb4/kadmin/kadm_server.c,v 1.4 1996/02/04 11:31:32 assar Exp $");
+RCSID("$Header: /src/packages/kth-krb/SourceRepository/krb4/kadmin/kadm_server.c,v 1.5 1996/03/22 14:16:26 bg Exp $");
 
 /* 
 kadm_ser_cpw - the server side of the change_password routine
@@ -73,7 +73,7 @@ kadm_ser_cpw(u_char *dat, int len, AUTH_DAT *ad, u_char **datout, int *outlen)
     strings[1] = ad->pinst;
     strings[2] = ad->prealm;
     strings[3] = NULL;
-    status=kadm_pw_check(pword, (des_cblock*)newkey, &pw_msg, strings);
+    status = kadm_pw_check(pword, &newkey, &pw_msg, strings);
     
     bzero(pword, sizeof(pword));
     bzero(dat, len);
