@@ -36,7 +36,7 @@ or implied warranty.
 
 #include "kadm_locl.h"
 
-RCSID("$Header: /afs/nada.kth.se/src/packages/kth-krb/SourceRepository/krb4/kadmin/kadmin.c,v 1.11 1996/02/04 09:23:50 assar Exp $");
+RCSID("$Header: /src/packages/kth-krb/SourceRepository/krb4/kadmin/kadmin.c,v 1.17 1996/03/24 06:53:14 assar Exp $");
 
 #define BAD_PW 1
 #define GOOD_PW 0
@@ -287,64 +287,69 @@ quit(void)
     exit(0);
 }
 
-static int inited = 0;
-
 static void
 do_init(int argc, char **argv)
 {
     struct passwd *pw;
     int c;
-#define OPTION_STRING "u:r:m"
+    int tflag;
+    char tktstring[MaxPathLen];
     
     bzero(myname, sizeof(myname));
 
-    if (!inited) {
-	/* 
-	 * This is only as a default/initial realm; we don't care 
-	 * about failure.
-	 */
-	if (krb_get_lrealm(default_realm, 1) != KSUCCESS)
-	    strcpy(default_realm, "NO.DEFAULT.REALM");
-	else if (krbrlm[0] == 0)
-	    strcpy(krbrlm, default_realm);
+    /* 
+     * This is only as a default/initial realm; we don't care 
+     * about failure.
+     */
+    if (krb_get_lrealm(default_realm, 1) != KSUCCESS)
+      strcpy(default_realm, "NO.DEFAULT.REALM");
+    else if (krbrlm[0] == 0)
+      strcpy(krbrlm, default_realm);
 
-	/* 
-	 * If we can reach the local realm, initialize to it.  Otherwise,
-	 * don't initialize.
-	 */
-	if (kadm_init_link(PWSERV_NAME, KRB_MASTER, krbrlm) != KADM_SUCCESS)
-	    bzero(krbrlm, sizeof(krbrlm));
-	else
-	    strcpy(krbrlm, default_realm);
+    /* 
+     * If we can reach the local realm, initialize to it.  Otherwise,
+     * don't initialize.
+     */
+    if (kadm_init_link(PWSERV_NAME, KRB_MASTER, krbrlm) != KADM_SUCCESS)
+      bzero(krbrlm, sizeof(krbrlm));
+    else
+      strcpy(krbrlm, default_realm);
 
-	while ((c = getopt(argc, argv, OPTION_STRING)) != EOF) 
-	    switch (c) {
-	      case 'u':
-		strncpy(myname, optarg, sizeof(myname) - 1);
-		break;
-	      case 'r':
-		bzero(default_realm, sizeof(default_realm));
-		strncpy(default_realm, optarg, sizeof(default_realm) - 1);
-		break;
-	      case 'm':
-		multiple++;
-		break;
-	      default:
-		usage();
-		break;
-	    }
-	if (optind < argc)
-	    usage();
-	if (!myname[0]) {
-	    pw = getpwuid((int) getuid());
-	    if (!pw) {
-		fprintf(stderr,
-			"You aren't in the password file.  Who are you?\n");
-		exit(1);
-	    }
-	    (void) strcpy(myname, pw->pw_name);
-	}
-	inited = 1;
+    tflag = 0;
+
+    while ((c = getopt(argc, argv, "u:r:mt")) != EOF) 
+      switch (c) {
+      case 'u':
+	strncpy(myname, optarg, sizeof(myname) - 1);
+	break;
+      case 'r':
+	bzero(default_realm, sizeof(default_realm));
+	strncpy(default_realm, optarg, sizeof(default_realm) - 1);
+	break;
+      case 'm':
+	multiple++;
+	break;
+      case 't':
+	tflag++;
+	break;
+      default:
+	usage();
+	break;
+      }
+    if (optind < argc)
+      usage();
+    if (!myname[0]) {
+      pw = getpwuid((int) getuid());
+      if (!pw) {
+	fprintf(stderr,
+		"You aren't in the password file.  Who are you?\n");
+	exit(1);
+      }
+      (void) strcpy(myname, pw->pw_name);
+    }
+    if (!tflag) {
+      (void) sprintf(tktstring, "/tmp/tkt_adm_%d",(int)getpid());
+      krb_set_tkt_string(tktstring);
     }
 }
 
@@ -353,7 +358,6 @@ main(int argc, char **argv)
 {
     int     sci_idx;
     int     code;
-    char tktstring[MaxPathLen];
 
     sci_idx = ss_create_invocation("admin", "2.0", (char *) NULL,
 				   &admin_cmds, &code);
@@ -361,9 +365,6 @@ main(int argc, char **argv)
 	ss_perror(sci_idx, code, "creating invocation");
 	exit(1);
     }
-    (void) sprintf(tktstring, "/tmp/tkt_adm_%d",(int)getpid());
-    krb_set_tkt_string(tktstring);
-
     do_init(argc, argv);
 
     printf("Welcome to the Kerberos Administration Program, version 2\n");
@@ -386,7 +387,7 @@ setvals(Kadm_vals *vals, char *string)
     SET_FIELD(KADM_NAME,vals->fields);
     SET_FIELD(KADM_INST,vals->fields);
     if ((status = kname_parse(vals->name, vals->instance, realm, string))) {
-	printf("kerberos error: %s\n", krb_err_txt[status]);
+	printf("kerberos error: %s\n", krb_get_err_text(status));
 	return status;
     }
     if (!realm[0])
@@ -550,30 +551,27 @@ void
 change_admin_password(int argc, char **argv)
 {
     des_cblock newkey;
-    u_int32_t low, high;
     int status;
-    char prompt_pw[BUFSIZ];
+    char pword[MAX_KPW_LEN];
+    char *pw_msg;
 
     if (argc != 1) {
 	printf("Usage: change_admin_password\n");
 	return;
     }
-    /* get the admin's password */
-    if (get_admin_password() != GOOD_PW)
-	return;
-
-    (void) sprintf(prompt_pw, "New password for %s.admin:",myname);
-    if (get_password(&low, &high, prompt_pw, DONTSWAP) == GOOD_PW) {
-	bcopy((char *)&low,(char *) newkey,4);
-	bcopy((char *)&high, (char *)(((int32_t *) newkey) + 1),4);
-	low = high = 0L;
-	if ((status = kadm_change_pw(newkey)) == KADM_SUCCESS)
-	    printf("Admin password changed\n");
-	else
-	    printf("kadm error: %s\n",error_message(status));
-	bzero((char *)newkey, sizeof(newkey));
-    } else
-	printf("Error reading password; password unchanged\n");
+    if (get_pw_new_pwd(pword, sizeof(pword), myname, "admin",
+		       default_realm, 1) == 0) {
+	 des_string_to_key(pword, &newkey);
+	 status = kadm_change_pw_plain(newkey, pword, &pw_msg);
+	 if(status == KADM_INSECURE_PW)
+	      printf("Insecure password: %s\n", pw_msg);
+	 else if (status == KADM_SUCCESS)
+	      printf("Admin password changed\n");
+	 else
+	      printf("kadm error: %s\n",error_message(status));
+	 bzero((char *)newkey, sizeof(newkey));
+	 bzero(pword, sizeof(pword));
+    }
     if (!multiple)
 	clean_up();
     return;
@@ -862,14 +860,3 @@ help(int argc, char **argv)
     }
     return;
 }
-#if 0
-static void
-go_home(str,x)
-char *str;
-int x;
-{
-    fprintf(stderr, "%s: %s\n", str, error_message(x));
-    clean_up();
-    exit(1);
-}
-#endif
