@@ -30,7 +30,7 @@ or implied warranty.
 
 #include "kadm_locl.h"
 
-RCSID("$Header: /afs/nada.kth.se/src/packages/kth-krb/SourceRepository/krb4/kadmin/kpasswd.c,v 1.8 1996/02/07 19:38:28 bg Exp $");
+RCSID("$Header: /src/packages/kth-krb/SourceRepository/krb4/kadmin/kpasswd.c,v 1.12 1996/03/11 09:21:56 bg Exp $");
 
 #ifdef NOENCRYPTION
 #define read_long_pw_string placebo_read_pw_string
@@ -47,113 +47,6 @@ usage(int value)
     exit(value);
 }
 
-static void
-go_home(char *str, int x)
-{
-    fprintf(stderr, str, x);
-    (void) dest_tkt();
-    exit(1);
-}
-
-#if 1
-/*
- * Check if pw is a good password.  Then return NULL, otherwise
- * return a string with an explanation
- */
-char *FascistCheck(char *pw, char *dictpath)
-{
-  return 0;			/* FOR NOW ALL PASSWORDS ARE GOOD! */
-}
-#endif
-
-#define DICTPATH "/usr/local/lib/pw_dict"
-
-static char *
-check_pw (char *pword)
-{
-    if (strlen(pword) == 0)
-	return "Null passwords are not allowed - Please enter a longer password.";
-    
-    if (strlen(pword) < MIN_KPW_LEN)
-	return "Password is to short - Please enter a longer password.";
-    
-    /* Don't allow all lower case passwords regardless of length */
-    {
-	char *t;
-	for (t = pword; *t && islower(*t); t++)
-	    ;
-	if (*t == 0)
-	    return "Please don't use an all-lower case password.\n\tUnusual capitalization, delimiter characters or digits are suggested.";
-    }
-
-    return FascistCheck (pword, DICTPATH);
-}
-
-static void
-get_pw_new_pwd(char *pword, int pwlen, char *name, char *inst,
-	       char *realm, int print_realm)
-{
-    char ppromp[40+ANAME_SZ+INST_SZ+REALM_SZ]; /* for the password prompt */
-    char npromp[40+ANAME_SZ+INST_SZ+REALM_SZ]; /* for the password prompt */
-    
-    char local_realm[REALM_SZ];
-    int status;
-    char *expl;
-    
-    /*
-     * We don't care about failure; this is to determine whether or
-     * not to print the realm in the prompt for a new password. 
-     */
-    (void) krb_get_lrealm(local_realm, 1);
-    
-    if (strcmp(local_realm, realm))
-	print_realm++;
-    
-    (void) sprintf(ppromp,"Old password for %s%s%s%s%s:",
-		   name, *inst ? "." : "", inst,
-		   print_realm ? "@" : "", print_realm ? realm : "");
-    if (read_long_pw_string(pword, pwlen-1, ppromp, 0)) {
-	fprintf(stderr, "Error reading old password.\n");
-	exit(1);
-    }
-
-    if ((status = krb_get_pw_in_tkt(name, inst, realm, PWSERV_NAME, 
-				    KADM_SINST, 1, pword)) != KSUCCESS) {
-	if (status == INTK_BADPW) {
-	    printf("Incorrect old password.\n");
-	    exit(0);
-	}
-	else {
-	    fprintf(stderr, "Kerberos error: %s\n", krb_err_txt[status]);
-	    exit(1);
-	}
-    }
-    bzero(pword, pwlen);
-    do {
-	char verify[MAX_KPW_LEN];
-	(void) sprintf(npromp,"New Password for %s%s%s%s%s:",
-		       name, *inst ? "." : "", inst,
-		       print_realm ? "@" : "", print_realm ? realm : "");
-	if (read_long_pw_string(pword, pwlen-1, npromp, 0))
-	    go_home("Error reading new password, password unchanged.\n",0);
-	expl = check_pw (pword);
-	if (expl) {
-	    printf("\n\t%s\n\n", expl);
-	    continue;
-	}
-	/* Now we got an ok password, verify it. */
-	(void) sprintf(npromp,"Verifying New Password for %s%s%s%s%s:",
-		       name, *inst ? "." : "", inst,
-		       print_realm ? "@" : "", print_realm ? realm : "");
-	if (read_long_pw_string(verify, MAX_KPW_LEN-1, npromp, 0))
-	    go_home("Error reading new password, password unchanged.\n",0);
-	if (strcmp(pword, verify) != 0) {
-	    printf("Verify failure - try again\n");
-	    expl = "";		/* continue */
-	}
-    } while (expl);
-}
-
 int
 main(int argc, char **argv)
 {
@@ -192,7 +85,7 @@ main(int argc, char **argv)
 	switch (c) {
 	  case 'u':
 	    if ((status = kname_parse(name, inst, realm, optarg))) {
-		fprintf(stderr, "Kerberos error: %s\n", krb_err_txt[status]);
+		fprintf(stderr, "Kerberos error: %s\n", krb_get_err_text(status));
 		exit(2);
 	    }
 	    if (realm[0])
@@ -255,7 +148,11 @@ main(int argc, char **argv)
     (void) sprintf(tktstring, "/tmp/tkt_cpw_%d",(int)getpid());
     krb_set_tkt_string(tktstring);
     
-    get_pw_new_pwd(pword, sizeof(pword), name, inst, realm, realm_given);
+    if (get_pw_new_pwd(pword, sizeof(pword), name, inst, realm,
+		       realm_given)) {
+      dest_tkt ();
+      exit(1);
+    }
     
     status = kadm_init_link("changepw", KRB_MASTER, realm);
     if (status != KADM_SUCCESS) 
