@@ -1,7 +1,7 @@
 /*
  * This software may now be redistributed outside the US.
  *
- * $Source: /afs/nada.kth.se/src/packages/kth-krb/SourceRepository/krb4/kadmin/ksrvutil.c,v $
+ * $Source: /src/packages/kth-krb/SourceRepository/krb4/kadmin/ksrvutil.c,v $
  *
  * $Locker:  $
  */
@@ -347,7 +347,6 @@ main(int argc, char **argv)
     int backup_keyfile_fd = -1;	/* compiler doesn't complain */
     char local_realm[REALM_SZ];	/* local kerberos realm */
     int c;
-    int i;
     int interactive = FALSE;
     int list = FALSE;
     int change = FALSE;
@@ -393,7 +392,7 @@ main(int argc, char **argv)
 		 KSUCCESS) {
 		   fprintf(stderr, "%s: principal %s: %s\n", progname,
 			   optarg,
-			   krb_err_txt[status]);
+			   krb_get_err_text(status));
 		   return 1;
 	      }
 	      break;
@@ -546,9 +545,17 @@ main(int argc, char **argv)
 		    (void) printf("Not changing this key.\n");
 		
 		if (change_this_key) {
-		    /* Initialize non shared random sequence old key. */
+		    /*
+		     * This is not a good choice of seed when/if the
+		     * key has been compromised so we also use a
+		     * random sequence number!
+		     */
 		    des_init_random_number_generator(&old_key);
-		    
+		    {
+		        unsigned char seqnum[8];
+			des_rand_data(seqnum, sizeof(seqnum));
+			des_set_sequence_number(seqnum);
+		    }
 		    /* 
 		     * Pick a new key and determine whether or not
 		     * it is safe to change
@@ -560,7 +567,7 @@ main(int argc, char **argv)
 		    else {
 			(void) bcopy(old_key, new_key, sizeof(new_key));
 			(void) fprintf(stderr, "%s: Key NOT changed: %s\n",
-				       progname, krb_err_txt[status]);
+				       progname, krb_get_err_text(status));
 			change_this_key = FALSE;
 		    }
 		}
