@@ -1,7 +1,7 @@
 #include "kadm_locl.h"
 #include "ksrvutil.h"
 
-RCSID("$Header: /afs/nada.kth.se/src/packages/kth-krb/SourceRepository/krb4/kadmin/ksrvutil_get.c,v 1.6 1996/02/09 23:30:13 assar Exp $");
+RCSID("$Header: /src/packages/kth-krb/SourceRepository/krb4/kadmin/ksrvutil_get.c,v 1.10 1996/03/24 06:57:43 assar Exp $");
 
 #define BAD_PW 1
 #define GOOD_PW 0
@@ -130,7 +130,7 @@ key_to_key(char *user, char *instance, char *realm, void *arg,
   return 0;
 }
 
-static int
+static void
 get_srvtab_ent(int fd, char *filename, char *name, char *inst, char *realm)
 {
   char chname[128];
@@ -164,7 +164,7 @@ get_srvtab_ent(int fd, char *filename, char *name, char *inst, char *realm)
     ret = kadm_add(&values);
   if (ret != KSUCCESS) {
     fprintf(stderr, "%s: Couldn't get srvtab entry for %s.%s: %s\n",
-	    progname, name, inst, krb_err_txt[ret]);
+	    progname, name, inst, krb_get_err_text(ret));
     return;
   }
   
@@ -192,7 +192,7 @@ get_srvtab_ent(int fd, char *filename, char *name, char *inst, char *realm)
     
   if(ret != KSUCCESS) {
     fprintf (stderr, "%s: Could not get a ticket for %s.%s@%s: %s\n",
-	     progname, name, inst, realm, krb_err_txt[ret]);
+	     progname, name, inst, realm, krb_get_err_text(ret));
     return;
   }
 
@@ -214,7 +214,7 @@ ksrvutil_kadm(int fd, char *filename, struct srv_ent *p)
   ret = kadm_init_link(PWSERV_NAME, KADM_SINST, u_realm);
   if (ret != KADM_SUCCESS) {
     fprintf(stderr, "%s: Couldn't initialize kadmin link: %s\n",
-	    progname, krb_err_txt[ret]);
+	    progname, krb_get_err_text(ret));
     leave(NULL, 1);
   }
   
@@ -227,7 +227,7 @@ ksrvutil_kadm(int fd, char *filename, struct srv_ent *p)
     /*
      *  create ticket file and get admin tickets
      */
-    sprintf(tktstring, "/tmp/tkt_ksrvutil_%d", getpid());
+    sprintf(tktstring, "/tmp/tkt_ksrvutil_%d", (int)getpid());
     krb_set_tkt_string(tktstring);
     destroyp = TRUE;
        
