@@ -12,22 +12,23 @@
  */
 
 #include "kuser_locl.h"
+#include <kafs.h>
 
-RCSID("$Header: /afs/nada.kth.se/src/packages/kth-krb/SourceRepository/krb4/kuser/kdestroy.c,v 1.3 1996/02/07 10:48:19 d91-jda Exp $");
+RCSID("$Header: /src/packages/kth-krb/SourceRepository/krb4/kuser/kdestroy.c,v 1.5 1996/03/24 06:57:45 assar Exp $");
 
 static char *pname;
 
 static void
 usage(void)
 {
-    fprintf(stderr, "Usage: %s [-f] [-q]\n", pname);
+    fprintf(stderr, "Usage: %s [-f] [-q] [-t]\n", pname);
     exit(1);
 }
 
 int
 main(int argc, char **argv)
 {
-    int     fflag=0, qflag=0, k_errno;
+    int     fflag=0, qflag=0, tflag = 0, k_errno;
     register char *cp;
 
     cp = strrchr (argv[0], '/');
@@ -43,11 +44,16 @@ main(int argc, char **argv)
 	    ++fflag;
 	else if (!strcmp(argv[1], "-q"))
 	    ++qflag;
+	else if (!strcmp(argv[1], "-t"))
+	    ++tflag;
 	else usage();
     }
 
     k_errno = dest_tkt();
 
+    if(!tflag && k_hasafs())
+      k_unlog();
+
     if (fflag) {
 	if (k_errno != 0 && k_errno != RET_TKFIL)
 	    exit(1);
