@@ -19,7 +19,7 @@
 
 #include "kuser_locl.h"
 
-RCSID("$Header: /afs/nada.kth.se/src/packages/kth-krb/SourceRepository/krb4/kuser/kinit.c,v 1.4 1996/02/09 23:30:31 assar Exp $");
+RCSID("$Header: /src/packages/kth-krb/SourceRepository/krb4/kuser/kinit.c,v 1.7 1996/03/11 09:22:02 bg Exp $");
 
 #define	LIFE	DEFAULT_TKT_LIFE /* lifetime of ticket in 5-minute units */
 
@@ -94,7 +94,7 @@ main(int argc, char **argv)
     if (username &&
 	(k_errno = kname_parse(aname, inst, realm, username))
 	!= KSUCCESS) {
-	fprintf(stderr, "%s: %s\n", progname, krb_err_txt[k_errno]);
+	fprintf(stderr, "%s: %s\n", progname, krb_get_err_text(k_errno));
 	iflag = rflag = 1;
 	username = NULL;
     }
@@ -148,7 +148,7 @@ main(int argc, char **argv)
 	 if (lifetime < 5)
 	      lifetime = 1;
 	 else
-	      lifetime /= krb_time_to_life(0, lifetime*60);
+	      lifetime = krb_time_to_life(0, lifetime*60);
 	 /* This should be changed if the maximum ticket lifetime */
 	 /* changes */
 	 if (lifetime > 255)
@@ -164,9 +164,9 @@ main(int argc, char **argv)
 				lifetime, 0);
     if (vflag) {
 	printf("Kerberos realm %s:\n", realm);
-	printf("%s\n", krb_err_txt[k_errno]);
+	printf("%s\n", krb_get_err_text(k_errno));
     } else if (k_errno) {
-	fprintf(stderr, "%s: %s\n", progname, krb_err_txt[k_errno]);
+	fprintf(stderr, "%s: %s\n", progname, krb_get_err_text(k_errno));
 	exit(1);
     }
     exit(0);
