@@ -10,17 +10,18 @@
 
 #include "kuser_locl.h"
 
-RCSID("$Header: /afs/nada.kth.se/src/packages/kth-krb/SourceRepository/krb4/kuser/klist.c,v 1.5 1996/02/07 11:04:40 d91-jda Exp $");
+RCSID("$Header: /src/packages/kth-krb/SourceRepository/krb4/kuser/klist.c,v 1.8 1996/03/11 09:22:03 bg Exp $");
 
 char   *whoami;			/* What was I invoked as?? */
 
 static char *
-short_date(time_t *dp)
+short_date(int32_t dp)
 {
     register char *cp;
+    time_t t = (time_t)dp;
 
-    if (*dp == (time_t)(-1L)) return "***  Never  *** ";
-    cp = ctime(dp) + 4;
+    if (t == (time_t)(-1L)) return "***  Never  *** ";
+    cp = ctime(&t) + 4;
     cp[15] = '\0';
     return (cp);
 }
@@ -55,7 +56,7 @@ display_tktfile(char *file, int tgt_test, int long_form)
     /* Open ticket file */
     if ((k_errno = tf_init(file, R_TKT_FIL))) {
 	if (!tgt_test)
-		fprintf(stderr, "%s: %s\n", whoami, krb_err_txt[k_errno]);
+		fprintf(stderr, "%s: %s\n", whoami, krb_get_err_text(k_errno));
 	exit(1);
     }
     /* Close ticket file */
@@ -70,21 +71,21 @@ display_tktfile(char *file, int tgt_test, int long_form)
     if ((k_errno = krb_get_tf_realm(file, prealm)) != KSUCCESS) {
 	if (!tgt_test)
 	    fprintf(stderr, "%s: can't find realm of ticket file: %s\n",
-		    whoami, krb_err_txt[k_errno]);
+		    whoami, krb_get_err_text(k_errno));
 	exit(1);
     }
 
     /* Open ticket file */
     if ((k_errno = tf_init(file, R_TKT_FIL))) {
 	if (!tgt_test)
-		fprintf(stderr, "%s: %s\n", whoami, krb_err_txt[k_errno]);
+		fprintf(stderr, "%s: %s\n", whoami, krb_get_err_text(k_errno));
 	exit(1);
     }
     /* Get principal name and instance */
     if ((k_errno = tf_get_pname(pname)) ||
 	(k_errno = tf_get_pinst(pinst))) {
 	    if (!tgt_test)
-		    fprintf(stderr, "%s: %s\n", whoami, krb_err_txt[k_errno]);
+		    fprintf(stderr, "%s: %s\n", whoami, krb_get_err_text(k_errno));
 	    exit(1);
     }
 
@@ -117,10 +118,10 @@ display_tktfile(char *file, int tgt_test, int long_form)
 	    continue;			/* not a tgt */
 	}
 	if (long_form) {
-	    (void) strcpy(buf1, short_date(&c.issue_date));
+	    (void) strcpy(buf1, short_date(c.issue_date));
 	    c.issue_date = krb_life_to_time(c.issue_date, c.lifetime);
 	    if (time(0) < (unsigned long) c.issue_date)
-	        (void) strcpy(buf2, short_date(&c.issue_date));
+	        (void) strcpy(buf2, short_date(c.issue_date));
 	    else
 	        (void) strcpy(buf2, ">>> Expired <<< ");
 	    printf("%s  %s  ", buf1, buf2);
