@@ -1,6 +1,6 @@
 /*
- * $Source: /afs/nada.kth.se/src/packages/kth-krb/SourceRepository/krb4/kuser/ksrvtgt.c,v $
- * $Author: d91-jda $
+ * $Source: /src/packages/kth-krb/SourceRepository/krb4/kuser/ksrvtgt.c,v $
+ * $Author: bg $
  *
  * Copyright 1988 by the Massachusetts Institute of Technology. 
  *
@@ -18,7 +18,7 @@
 #include <conf.h>
 
 const char rcsid[] =
-    "$Header: /afs/nada.kth.se/src/packages/kth-krb/SourceRepository/krb4/kuser/ksrvtgt.c,v 1.1.1.1 1995/10/23 11:18:56 d91-jda Exp $";
+    "$Header: /src/packages/kth-krb/SourceRepository/krb4/kuser/ksrvtgt.c,v 1.3 1996/03/11 09:22:04 bg Exp $";
 
 main(argc,argv)
     int argc;
@@ -55,6 +55,6 @@ main(argc,argv)
     code = krb_get_svc_in_tkt(argv[1], argv[2], realm,
 			      "krbtgt", realm, 1, srvtab);
     if (code)
-	fprintf(stderr, "%s\n", krb_err_txt[code]);
+	fprintf(stderr, "%s\n", krb_get_err_text(code));
     exit(code);
 }
