@@ -1,7 +1,7 @@
 /*
- * $Source: /afs/nada.kth.se/src/packages/kth-krb/SourceRepository/krb4/lib/kadm/kadm.h,v $
- * $Author: bg $
- * $Header: /afs/nada.kth.se/src/packages/kth-krb/SourceRepository/krb4/lib/kadm/kadm.h,v 1.7 1996/02/07 10:59:06 bg Exp $
+ * $Source: /src/packages/kth-krb/SourceRepository/krb4/lib/kadm/kadm.h,v $
+ * $Author: assar $
+ * $Header: /src/packages/kth-krb/SourceRepository/krb4/lib/kadm/kadm.h,v 1.8 1996/03/24 06:57:53 assar Exp $
  *
  * Copyright 1988 by the Massachusetts Institute of Technology.
  *
@@ -114,8 +114,6 @@ MODACL
 #define MOD_ENT      4
 #define GET_ENT      5
 
-#define CHANGE_PW_PLAIN 17
-
 void prin_vals __P((Kadm_vals *));
 int stv_long __P((u_char *, u_int32_t *, int, int));
 int vts_long __P((u_int32_t, u_char **, int));
