@@ -34,7 +34,7 @@ or implied warranty.
 
 #include "kadm_locl.h"
 
-RCSID("$Header: /afs/nada.kth.se/src/packages/kth-krb/SourceRepository/krb4/lib/kadm/kadm_cli_wrap.c,v 1.9 1996/02/07 10:48:31 d91-jda Exp $");
+RCSID("$Header: /src/packages/kth-krb/SourceRepository/krb4/lib/kadm/kadm_cli_wrap.c,v 1.10 1996/03/24 06:57:54 assar Exp $");
 
 #ifndef NULL
 #define NULL 0
@@ -135,7 +135,8 @@ kadm_cli_conn(void)
 	(void) signal(SIGPIPE, opipe);
 	return KADM_NO_HERE;		/* couldnt find out who we are */
     }
-    if (setsockopt(client_parm.admin_fd, SOL_SOCKET, SO_KEEPALIVE, &on,
+    if (setsockopt(client_parm.admin_fd, SOL_SOCKET, SO_KEEPALIVE,
+		   (void *)&on,
 		   sizeof(on)) < 0) {
 	(void) close(client_parm.admin_fd);
 	client_parm.admin_fd = -1;
