@@ -3,6 +3,8 @@
 
 #include <sys/bitypes.h>
 #include <sys/cdefs.h>
+/* sys/ioctl.h must be included manually before kafs.h */
+
 /*
  */
 #define AFSCALL_PIOCTL 20
@@ -15,6 +17,8 @@
 #define VIOCSETTOK _VICEIOCTL(3)
 #define VIOCUNLOG  _VICEIOCTL(9)
 
+#define VIOC_FILE_CELL_NAME _VICEIOCTL(30)
+
 struct ViceIoctl {
   caddr_t in, out;
   short in_size;
