@@ -1,7 +1,7 @@
 /*
- * $Source: /afs/nada.kth.se/src/packages/kth-krb/SourceRepository/krb4/lib/kdb/krb_db.h,v $
- * $Author: assar $
- * $Header: /afs/nada.kth.se/src/packages/kth-krb/SourceRepository/krb4/lib/kdb/krb_db.h,v 1.7 1996/02/10 12:58:53 assar Exp $ 
+ * $Source: /src/packages/kth-krb/SourceRepository/krb4/lib/kdb/krb_db.h,v $
+ * $Author: d91-jda $
+ * $Header: /src/packages/kth-krb/SourceRepository/krb4/lib/kdb/krb_db.h,v 1.8 1996/03/24 06:46:53 d91-jda Exp $ 
  *
  * Copyright 1987, 1988 by the Massachusetts Institute of Technology. 
  *
@@ -110,7 +110,13 @@ int kerb_db_set_name __P((char *));
 #define KDB_GET_PROMPT 1
 #define KDB_GET_TWICE  2
 
-long kdb_get_master_key __P((int, des_cblock *, des_key_schedule));
+void kdb_encrypt_key __P((des_cblock *, des_cblock *, des_cblock *, 
+			  struct des_ks_struct *, int));
+int kdb_new_get_master_key __P((des_cblock *, des_key_schedule));
+int kdb_get_new_master_key __P((des_cblock *, des_key_schedule, int));
+int kdb_kstash __P((des_cblock *, char *));
+long kdb_verify_master_key __P((des_cblock *, struct des_ks_struct *, FILE *));
+
 
 #include <stdio.h>
 long kdb_verify_master_key __P((des_cblock *, des_key_schedule, FILE *));
