@@ -26,7 +26,7 @@ or implied warranty.
 
 #include "kdb_locl.h"
 
-RCSID("$Header: /afs/nada.kth.se/src/packages/kth-krb/SourceRepository/krb4/lib/kdb/krb_dbm.c,v 1.9 1996/02/07 10:48:36 d91-jda Exp $");
+RCSID("$Header: /src/packages/kth-krb/SourceRepository/krb4/lib/kdb/krb_dbm.c,v 1.11 1996/03/24 07:07:19 assar Exp $");
 
 #ifdef NDBM
 #include <ndbm.h>
@@ -128,9 +128,8 @@ typedef char DBM;
 
 static char *gen_dbsuffix __P((char *db_name, char *sfx));
 
-static char *gen_dbsuffix(db_name, sfx)
-     char *db_name;
-     char *sfx;
+static char *
+gen_dbsuffix(char *db_name, char *sfx)
 {
     char *dbsuffix;
     
@@ -147,10 +146,7 @@ static void
 decode_princ_key __P((datum *key, char *name, char *instance));
 
 static void
-decode_princ_key(key, name, instance)
-     datum *key;
-     char *name;
-     char *instance;
+decode_princ_key(datum *key, char *name, char *instance)
 {
     strncpy(name, key->dptr, ANAME_SZ);
     strncpy(instance, key->dptr + ANAME_SZ, INST_SZ);
@@ -162,20 +158,20 @@ static void
 encode_princ_contents __P((datum *contents, Principal *principal));
 
 static void
-encode_princ_contents(contents, principal)
-     datum *contents;
-     Principal *principal;
+encode_princ_contents(datum *contents, Principal *principal)
 {
     contents->dsize = sizeof(*principal);
     contents->dptr = (char *) principal;
 }
 
-static void decode_princ_contents (datum *contents, Principal *principal)
+static void
+decode_princ_contents (datum *contents, Principal *principal)
 {
     bcopy(contents->dptr, (char *) principal, sizeof(*principal));
 }
 
-static void encode_princ_key (datum *key, char *name, char *instance)
+static void
+encode_princ_key (datum *key, char *name, char *instance)
 {
     static char keystring[ANAME_SZ + INST_SZ];
 
@@ -226,8 +222,7 @@ static int
 kerb_dbl_lock __P((int mode));
 
 static int
-kerb_dbl_lock(mode)
-     int mode;
+kerb_dbl_lock(int mode)
 {
     int flock_mode;
     
@@ -261,7 +256,8 @@ kerb_dbl_lock(mode)
 
 static void kerb_dbl_unlock __P((void));
 
-static void kerb_dbl_unlock()
+static void
+kerb_dbl_unlock()
 {
     if (!mylock) {		/* lock already unlocked */
 	fprintf(stderr, "Kerberos database lock not locked when unlocking.\n");
@@ -281,8 +277,7 @@ int
 kerb_db_set_lockmode __P((int mode));
 
 int
-kerb_db_set_lockmode(mode)
-     int mode;
+kerb_db_set_lockmode(int mode)
 {
     int old = non_blocking;
     non_blocking = mode;
@@ -327,8 +322,7 @@ int
 kerb_db_set_name __P((char *name));
 
 int
-kerb_db_set_name(name)
-     char *name;
+kerb_db_set_name(char *name)
 {
     DBM *db;
 
@@ -380,8 +374,7 @@ static time_t
 kerb_start_update __P((char *db_name));
 
 static time_t
-kerb_start_update(db_name)
-     char *db_name;
+kerb_start_update(char *db_name)
 {
     char *okname = gen_dbsuffix(db_name, ".ok");
     time_t age = kerb_get_db_age();
@@ -398,9 +391,7 @@ static int
 kerb_end_update __P((char *db_name, time_t age));
 
 static int
-kerb_end_update(db_name, age)
-     char *db_name;
-     time_t age;
+kerb_end_update(char *db_name, time_t age)
 {
     int fd;
     int retval = 0;
@@ -444,8 +435,8 @@ kerb_start_read()
 
 static int kerb_end_read __P((time_t age));
 
-static int kerb_end_read(age)
-     time_t age;
+static int
+kerb_end_read(time_t age)
 {
     if (kerb_get_db_age() != age || age == -1) {
 	return -1;
@@ -457,8 +448,7 @@ static int kerb_end_read(age)
  * Create the database, assuming it's not there.
  */
 int
-kerb_db_create(db_name)
-     char *db_name;
+kerb_db_create(char *db_name)
 {
     char *okname = gen_dbsuffix(db_name, ".ok");
     int fd;
@@ -510,9 +500,7 @@ int
 kerb_db_rename __P((char *from, char *to));
 
 int
-kerb_db_rename(from, to)
-     char *from;
-     char *to;
+kerb_db_rename(char *from, char *to)
 {
 #ifdef HAVE_NEW_DB
     char *fromdb = gen_dbsuffix (from, ".db");
@@ -557,8 +545,9 @@ kerb_db_rename(from, to)
  * found , and whether there were more than requested. 
  */
 
-int kerb_db_get_principal (char *name, char *inst, Principal *principal, 
-			   unsigned int max, int *more)
+int
+kerb_db_get_principal (char *name, char *inst, Principal *principal, 
+		       unsigned int max, int *more)
 {
     int     found = 0, code;
     int     wildp, wildi;
@@ -714,9 +703,8 @@ int
 kerb_db_put_principal __P((Principal *principal, unsigned int max));
 
 int
-kerb_db_put_principal(principal, max)
-     Principal *principal;	/* number of principal structs to */
-     unsigned int max;		/* update */
+kerb_db_put_principal(Principal *principal,
+		      unsigned max)
 
 {
     int found;
@@ -736,12 +724,10 @@ void
 kerb_db_get_stat __P((DB_stat *s));
 
 void
-kerb_db_get_stat(s)
-     DB_stat *s;
+kerb_db_get_stat(DB_stat *s)
 {
     gettimeofday(&timestamp, NULL);
 
-
     s->cpu = 0;
     s->elapsed = 0;
     s->dio = 0;
@@ -759,8 +745,7 @@ void
 kerb_db_put_stat __P((DB_stat *s));
 
 void
-kerb_db_put_stat(s)
-     DB_stat *s;
+kerb_db_put_stat(DB_stat *s)
 {
 }
 
@@ -768,8 +753,7 @@ void
 delta_stat __P((DB_stat *a, DB_stat *b, DB_stat *c));
 
 void
-delta_stat(a, b, c)
-     DB_stat *a, *b, *c;
+delta_stat(DB_stat *a, DB_stat *b, DB_stat *c)
 {
     /* c = a - b then b = a for the next time */
 
@@ -797,12 +781,13 @@ int
 kerb_db_get_dba __P((char *dba_name, char *dba_inst, Dba *dba, unsigned int max, int *more));
 
 int
-kerb_db_get_dba(dba_name, dba_inst, dba, max, more)
-     char *dba_name;		/* could have wild card */
-     char *dba_inst;		/* could have wild card */
-     Dba *dba;			/* max number of name structs to return */
-     unsigned int max;		/* where there more than 'max' tuples? */
-     int *more;
+kerb_db_get_dba(char *dba_name, char *dba_inst, Dba *dba,
+		unsigned max,
+		int *more)
+		/* could have wild card */
+		/* could have wild card */
+		/* max number of name structs to return */
+		/* where there more than 'max' tuples? */
 {
     *more = 0;
     return (0);
