@@ -36,41 +36,132 @@ or implied warranty.
 
 #include <kdc.h>
 
-RCSID("$Header: /afs/nada.kth.se/src/packages/kth-krb/SourceRepository/krb4/lib/kdb/krb_kdb_utils.c,v 1.7 1996/02/10 12:58:47 assar Exp $");
+RCSID("$Header: /src/packages/kth-krb/SourceRepository/krb4/lib/kdb/krb_kdb_utils.c,v 1.10 1996/03/24 20:55:02 assar Exp $");
 
-long 
-kdb_get_master_key(int prompt, des_cblock (*master_key), struct des_ks_struct *master_key_sched)
+/* always try /.k for backwards compatibility */
+static char *master_key_files[] = { MKEYFILE, "/.k", NULL };
+
+int kdb_new_get_master_key(des_cblock *key, des_key_schedule schedule)
 {
   int kfile;
+  int i;
+  char buf[1024];
 
-  if (prompt == KDB_GET_PROMPT || prompt == KDB_GET_TWICE) {
-#ifdef NOENCRYPTION
-      placebo_read_password(master_key,
-			    "\nEnter Kerberos master key: ",
-			    prompt == KDB_GET_TWICE);
+  char **mkey;
+
+  for(mkey = master_key_files; *mkey; mkey++){
+      kfile = open(*mkey, O_RDONLY);
+      if(kfile < 0 && errno != ENOENT)
+	  fprintf(stderr, "Failed to open master key file \"%s\": %s\n", 
+		  *mkey,
+		  k_strerror(errno));
+      if(kfile >= 0)
+	  break;
+  }
+  if(*mkey){
+      int bytes;
+      bytes = read(kfile, (char*)key, sizeof(des_cblock));
+      close(kfile);
+      if(bytes == sizeof(des_cblock)){
+	  des_key_sched(key, schedule);
+	  return 0;
+      }
+      fprintf(stderr, "Could only read %d bytes from master key file %s\n", 
+	      bytes, *mkey);
+  }else{
+      fprintf(stderr, "No master key file found.\n");
+  }
+
+  
+  i=0;
+  while(i < 3){
+      des_read_pw_string(buf, sizeof(buf), "Enter master key: ", 0);
+
+      /* buffer now contains either an old format master key password or a
+       * new format base64 encoded master key
+       */
+      
+      /* try to verify as old password */
+      des_string_to_key(buf, key);
+      des_key_sched(key, schedule);
+      
+      if(kdb_verify_master_key(key, schedule, NULL) != -1){
+	  memset(buf, 0, sizeof(buf));
+	  return 0;
+      }
+      
+      /* failed test, so must be base64 encoded */
+      
+      if(base64_decode(buf, key) == 8){
+	  des_key_sched(key, schedule);
+	  if(kdb_verify_master_key(key, schedule, NULL) != -1){
+	      memset(buf, 0, sizeof(buf));
+	      return 0;
+	  }
+      }
+      
+      memset(buf, 0, sizeof(buf));
+      fprintf(stderr, "Failed to verify master key.\n");
+      i++;
+  }
+  
+  /* life sucks */
+  fprintf(stderr, "You loose.\n");
+  exit(1);
+}
+
+int kdb_new_get_new_master_key(des_cblock *key, des_key_schedule schedule, 
+			       int verify)
+{
+  char buf[1024];
+#ifndef RANDOM_MKEY
+  des_read_password(key, "\nEnter Kerberos master key: ", verify);
+  printf ("\n");
 #else
-      des_read_password(master_key,
-			     "\nEnter Kerberos master key: ",
-			prompt == KDB_GET_TWICE);
+  des_rand_data(key, sizeof(des_cblock));
+  des_key_sched(key, schedule);
+  
+  des_read_pw_string(buf, sizeof(buf), "Enter master key seed: ", 0);
+  des_cbc_cksum((des_cblock*)buf, key, sizeof(buf), schedule, key);
+  memset(buf, 0, sizeof(buf));
 #endif
-      printf ("\n");
-  }
-  else {
-    kfile = open(MKEYFILE, O_RDONLY, 0600);
-    if (kfile < 0) {
-      /* oh, for com_err_ */
-      return (-1);
-    }
-    if (read(kfile, (char *) master_key, 8) != 8) {
-      return (-1);
-    }
-    close(kfile);
-  }
+  des_key_sched(key, schedule);
+  return 0;
+}
 
-#ifndef NOENCRYPTION
-  des_key_sched(master_key,master_key_sched);
+int kdb_get_master_key(int prompt, des_cblock *master_key, 
+		       struct des_ks_struct *master_key_sched)
+{
+  int kfile;
+  char buf[1024];
+  unsigned char *p, *q;
+
+  int ask = (prompt == KDB_GET_TWICE);
+#ifndef RANDOM_MKEY
+  ask |= (prompt == KDB_GET_PROMPT);
 #endif
-  return (0);
+  
+  if(ask)
+    kdb_new_get_new_master_key(master_key, master_key_sched, 
+			       prompt == KDB_GET_TWICE);
+  else
+    kdb_new_get_master_key(master_key, master_key_sched);
+  return 0;
+}
+
+int kdb_kstash(des_cblock *master_key, char *file)
+{
+  int kfile;
+  kfile = open(file, O_TRUNC | O_RDWR | O_CREAT, 0600);
+  if (kfile < 0) {
+    return -1;
+  }
+  if (write(kfile, (char *) master_key, sizeof(des_cblock)) != sizeof(des_cblock)) {
+    close(kfile);
+    return -1;
+  }
+  close(kfile);
+  return 0;
 }
 
 /* The old algorithm used the key schedule as the initial vector which
@@ -143,8 +234,10 @@ kdb_verify_master_key (des_cblock *master_key, struct des_ks_struct *master_key_
   if (n && (out != (FILE *) NULL)) {
     fprintf(out, "\n\07\07verify_master_key: Invalid master key; ");
     fprintf(out, "does not match database.\n");
-    return (-1);
   }
+  if(n)
+    return (-1);
+
   if (out != (FILE *) NULL) {
     fprintf(out, "\nMaster key entered.  BEWARE!\07\07\n");
     fflush(out);
