@@ -24,7 +24,13 @@ or implied warranty.
 
   */
 
+#include "krb_locl.h"
+
+RCSID("$Header: /src/packages/kth-krb/SourceRepository/krb4/lib/krb/debug_decl.c,v 1.3 1996/03/18 16:32:41 bg Exp $");
+
 /* Declare global debugging variables. */
 
+#ifndef KRB_NDEB
 int krb_ap_req_debug = 0;
 int krb_debug = 0;
+#endif
