@@ -26,7 +26,7 @@ or implied warranty.
 
 #include "krb_locl.h"
 
-RCSID("$Header: /afs/nada.kth.se/src/packages/kth-krb/SourceRepository/krb4/lib/krb/get_ad_tkt.c,v 1.5 1995/12/07 10:55:24 assar Exp $");
+RCSID("$Header: /src/packages/kth-krb/SourceRepository/krb4/lib/krb/get_ad_tkt.c,v 1.6 1996/03/18 16:32:42 bg Exp $");
 
 static int swap_bytes;
 
@@ -58,8 +58,10 @@ pkt_clen(KTEXT pkt)
 
     clen = (int) temp;
 
+#ifndef KRB_NDEB
     if (krb_debug)
 	fprintf(stderr, "Clen is %d\n",clen);
+#endif
     return(clen);
 }
 
@@ -219,7 +221,9 @@ get_ad_tkt(char *service, char *sinstance, char *realm, int lifetime)
     /* Attempt to decrypt it */
 
     des_key_sched(&cr.session,key_s);
+#ifndef KRB_NDEB
     if (krb_debug)  fprintf(stderr, "About to do decryption ...\n");
+#endif
     des_pcbc_encrypt((des_cblock *)cip->dat,(des_cblock *)cip->dat,
                  (long) cip->length,key_s,&cr.session,0);
 #endif /* !NOENCRYPTION */
