@@ -26,7 +26,7 @@ or implied warranty.
 
 #include "krb_locl.h"
 
-RCSID("$Header: /afs/nada.kth.se/src/packages/kth-krb/SourceRepository/krb4/lib/krb/get_in_tkt.c,v 1.4 1996/02/07 10:48:38 d91-jda Exp $");
+RCSID("$Header: /src/packages/kth-krb/SourceRepository/krb4/lib/krb/get_in_tkt.c,v 1.4 1996/02/07 10:48:38 d91-jda Exp $");
 
 /*
  * This file contains two routines: passwd_to_key() converts
@@ -129,7 +129,7 @@ krb_get_pw_in_tkt(char *user, char *instance, char *realm, char *service, char *
 
 #ifdef NOENCRYPTION
 /*
- * $Source: /afs/nada.kth.se/src/packages/kth-krb/SourceRepository/krb4/lib/krb/get_in_tkt.c,v $
+ * $Source: /src/packages/kth-krb/SourceRepository/krb4/lib/krb/get_in_tkt.c,v $
  * $Author: d91-jda $
  *
  * Copyright 1985, 1986, 1987, 1988 by the Massachusetts Institute
@@ -145,7 +145,7 @@ krb_get_pw_in_tkt(char *user, char *instance, char *realm, char *service, char *
 
 #ifndef	lint
 static char rcsid_read_password_c[] =
-"Bones$Header: /afs/nada.kth.se/src/packages/kth-krb/SourceRepository/krb4/lib/krb/get_in_tkt.c,v 1.4 1996/02/07 10:48:38 d91-jda Exp $";
+"Bones$Header: /src/packages/kth-krb/SourceRepository/krb4/lib/krb/get_in_tkt.c,v 1.4 1996/02/07 10:48:38 d91-jda Exp $";
 #endif	/* lint */
 
 #include <des.h>
