@@ -26,7 +26,7 @@ or implied warranty.
 
 #include "krb_locl.h"
 
-RCSID("$Header: /afs/nada.kth.se/src/packages/kth-krb/SourceRepository/krb4/lib/krb/in_tkt.c,v 1.5 1995/12/07 10:56:05 assar Exp $");
+RCSID("$Header: /src/packages/kth-krb/SourceRepository/krb4/lib/krb/in_tkt.c,v 1.6 1996/03/18 16:32:43 bg Exp $");
 
 #include <sys/file.h>
 #include <sys/types.h>
@@ -62,8 +62,10 @@ in_tkt(char *pname, char *pinst)
     if (lstat(file,&buf) == 0) {
 	if (buf.st_uid != me || !(buf.st_mode & S_IFREG) ||
 	    buf.st_mode & 077) {
+#ifndef KRB_NDEB
 	    if (krb_debug)
 		fprintf(stderr,"Error initializing %s",file);
+#endif
 	    return(KFAILURE);
 	}
 	/* file already exists, and permissions appear ok, so nuke it */
@@ -90,38 +92,56 @@ in_tkt(char *pname, char *pinst)
     if (me != metoo) {
 	if (k_setreuid(metoo, me) < 0) {
 	    /* can't switch??? barf! */
+#ifndef KRB_NDEB
 	    if (krb_debug)
 		perror("in_tkt: setreuid");
+#endif
 	    return(KFAILURE);
 	} else
+	  {
+#ifndef KRB_NDEB
 	    if (krb_debug)
 	      fprintf(stderr, "swapped UID's %d and %d\n",(int)metoo,(int)me);
+#endif
+	  }
     }
     if ((tktfile = creat(file,0600)) < 0) {
+#ifndef KRB_NDEB
 	if (krb_debug)
 	    fprintf(stderr,"Error initializing %s",TKT_FILE);
+#endif
         return(KFAILURE);
     }
     if (me != metoo) {
 	if (k_setreuid(me, metoo) < 0) {
 	    /* can't switch??? barf! */
+#ifndef KRB_NDEB
 	    if (krb_debug)
 		perror("in_tkt: setreuid2");
+#endif
 	    return(KFAILURE);
 	} else
+	  {
+#ifndef KRB_NDEB
 	    if (krb_debug)
 	      fprintf(stderr, "swapped UID's %d and %d\n",(int)me,(int)metoo);
+#endif
+	  }
     }
     if (lstat(file,&buf) < 0) {
+#ifndef KRB_NDEB
 	if (krb_debug)
 	    fprintf(stderr,"Error initializing %s",TKT_FILE);
+#endif
         return(KFAILURE);
     }
 
     if (buf.st_uid != me || !(buf.st_mode & S_IFREG) ||
         buf.st_mode & 077) {
+#ifndef KRB_NDEB
 	if (krb_debug)
 	    fprintf(stderr,"Error initializing %s",TKT_FILE);
+#endif
         return(KFAILURE);
     }
 
