@@ -1,12 +1,12 @@
 #include "krb_locl.h"
 
-RCSID("$Header: /afs/nada.kth.se/src/packages/kth-krb/SourceRepository/krb4/lib/krb/k_strerror.c,v 1.3 1995/11/12 20:22:13 d91-jda Exp $");
+RCSID("$Header: /src/packages/kth-krb/SourceRepository/krb4/lib/krb/k_strerror.c,v 1.4 1996/03/18 16:32:44 bg Exp $");
 
 const char *
 k_strerror(int errnum)
 {
 #ifdef HAVE_STRERROR
-  return strerror(errnum);
+  return (const char *) strerror(errnum);
 #else
   extern int sys_nerr;
   extern char *sys_errlist[];
