@@ -1,7 +1,7 @@
 /*
- * $Source: /afs/nada.kth.se/src/packages/kth-krb/SourceRepository/krb4/lib/krb/krb.h,v $
- * $Author: d91-jda $
- * $Header: /afs/nada.kth.se/src/packages/kth-krb/SourceRepository/krb4/lib/krb/krb.h,v 1.13 1996/02/07 10:48:42 d91-jda Exp $ 
+ * $Source: /src/packages/kth-krb/SourceRepository/krb4/lib/krb/krb.h,v $
+ * $Author: bg $
+ * $Header: /src/packages/kth-krb/SourceRepository/krb4/lib/krb/krb.h,v 1.18 1996/03/11 09:22:06 bg Exp $ 
  *
  * Copyright 1987, 1988 by the Massachusetts Institute of Technology. 
  *
@@ -34,6 +34,10 @@ extern int req_act_vno; /* in cr_err_reply.c NOT defined in server code */
 #define		MAX_KRB_ERRORS	256
 extern const char *krb_err_txt[MAX_KRB_ERRORS];
 
+/* Use this function rather than indexing in krb_err_txt */
+const char *krb_get_err_text __P((int code));
+
+
 /* General definitions */
 #define		KSUCCESS	0
 #define		KFAILURE	255
@@ -346,9 +350,15 @@ int k_flock __P((int fd, int operation));
 struct tm;
 struct tm *k_localtime __P((u_int32_t *));
 const char *k_strerror __P((int errnum));
+int k_setreuid(int r, int e);
+int k_getsockinst __P((int fd, char *inst));
+int k_getportbyname __P((const char *service, const char *proto, int default_port));
+
+#include <sys/types.h> /* to get u_char */
+#include <netinet/in.h>
+int k_get_all_addrs (struct in_addr **l);
 
 /* --- Random prototypes */
-#include <sys/types.h> /* to get u_char */
 
 /* Host address comparison */
 int krb_equiv __P((u_int32_t, u_int32_t));
@@ -421,8 +431,8 @@ int krb_get_tf_fullname __P((char *, char *, char *, char *));
 int krb_get_tf_realm __P((char *, char *));
 int krb_kntoln __P((AUTH_DAT *, char *));
 int krb_mk_req __P((KTEXT , char *, char *, char *, int32_t));
-int krb_net_read __P((int , char *, int));
-int krb_net_write __P((int , char *, int));
+int krb_net_read __P((int , void *, size_t));
+int krb_net_write __P((int , void *, size_t));
 int krb_rd_err __P((u_char *, u_int32_t, int32_t *, MSG_DAT *));
 int krb_rd_req __P((KTEXT , char *, char *, int32_t, AUTH_DAT *, char *));
 int krb_recvauth __P((int32_t, int, KTEXT, char *, char *, struct sockaddr_in *, struct sockaddr_in *, AUTH_DAT *, char *, struct des_ks_struct *, char *));
