@@ -26,7 +26,7 @@ or implied warranty.
 
 #include "krb_locl.h"
 
-RCSID("$Header: /afs/nada.kth.se/src/packages/kth-krb/SourceRepository/krb4/lib/krb/krb_err_txt.c,v 1.3 1996/02/04 15:06:59 assar Exp $");
+RCSID("$Header: /src/packages/kth-krb/SourceRepository/krb4/lib/krb/krb_err_txt.c,v 1.6 1996/03/11 09:22:08 bg Exp $");
 
 /*
  * This file contains an array of error text strings.
@@ -292,3 +292,13 @@ const char *krb_err_txt[256] = {
   "(reserved)",
   "Generic kerberos error (kfailure)",			/* 255 */
 };
+
+static const char err_failure[] = "Illegal error code passed (krb_get_err_text)";
+
+const char *
+krb_get_err_text(int code)
+{
+  if(code < 0 || code >= MAX_KRB_ERRORS)
+    return err_failure;
+  return krb_err_txt[code];
+}
