@@ -26,7 +26,7 @@ or implied warranty.
 
 #include "krb_locl.h"
 
-RCSID("$Header: /afs/nada.kth.se/src/packages/kth-krb/SourceRepository/krb4/lib/krb/krb_get_in_tkt.c,v 1.7 1996/02/07 10:48:43 d91-jda Exp $");
+RCSID("$Header: /src/packages/kth-krb/SourceRepository/krb4/lib/krb/krb_get_in_tkt.c,v 1.9 1996/03/18 16:32:44 bg Exp $");
 
 #include <sys/time.h>
 
@@ -52,8 +52,10 @@ pkt_clen(KTEXT pkt)
 
     clen = (int) temp;
 
+#ifndef KRB_NDEB
     if (krb_debug)
 	printf("Clen is %d\n",clen);
+#endif
     return(clen);
 }
 
@@ -303,19 +305,6 @@ krb_get_in_tkt(char *user, char *instance, char *realm,
 					   code */
     }
 
-#if 0
-    /* initialize ticket cache */
-    if (in_tkt(user,instance) != KSUCCESS)
-	return(INTK_ERR);
-
-    /* stash ticket, session key, etc. for future use */
-    if ((kerror = save_credentials(s_name, s_instance, rlm, ses,
-				  lifetime, kvno, tkt, t_local.tv_sec)))
-	return(kerror);
-
-#endif
-
-
     /* initialize ticket cache */
 
     if (tf_create(TKT_FILE) != KSUCCESS)
