@@ -32,6 +32,7 @@
 #ifdef HAVE_SYS_SELECT_H
 #include <sys/select.h>
 #endif
+#include <sys/socket.h>
 #include <netinet/in.h>
 #include <arpa/inet.h>
 #include <netdb.h>
@@ -42,8 +43,10 @@
 /* --- */
 
 /* Globals! */
+#ifndef KRB_NDEB
 extern int krb_debug;
 extern int krb_ap_req_debug;
+#endif
 
 /* Utils */
 char *pkt_cipher __P((KTEXT));
