@@ -31,13 +31,10 @@ or implied warranty.
 
 #include "krb_locl.h"
 
-RCSID("$Header: /afs/nada.kth.se/src/packages/kth-krb/SourceRepository/krb4/lib/krb/kuserok.c,v 1.4 1995/12/07 11:00:35 assar Exp $");
+RCSID("$Header: /src/packages/kth-krb/SourceRepository/krb4/lib/krb/kuserok.c,v 1.5 1996/03/24 15:12:56 bg Exp $");
 
 #include <pwd.h>
 #include <sys/param.h>
-#include <sys/socket.h>
-#include <sys/stat.h>
-#include <sys/file.h>
 
 #define OK 0
 #define NOTOK 1
