@@ -26,15 +26,13 @@ or implied warranty.
 
 #include "krb_locl.h"
 
-RCSID("$Header: /afs/nada.kth.se/src/packages/kth-krb/SourceRepository/krb4/lib/krb/send_to_kdc.c,v 1.9 1996/02/09 23:51:39 assar Exp $");
-
-#include <sys/socket.h>
+RCSID("$Header: /src/packages/kth-krb/SourceRepository/krb4/lib/krb/send_to_kdc.c,v 1.12 1996/03/24 15:12:57 bg Exp $");
 
 #define S_AD_SZ sizeof(struct sockaddr_in)
 
 static int krb_udp_port = 0;
 
-static char *prog = "send_to_kdc";
+static const char *prog = "send_to_kdc";
 static send_recv(KTEXT pkt, KTEXT rpkt, int f,
 		 struct sockaddr_in *_to, struct sockaddr_in *addrs,
 		 int h_hosts);
@@ -80,8 +78,7 @@ send_to_kdc(KTEXT pkt, KTEXT rpkt, char *realm)
     int n_hosts;
     int retval;
     struct sockaddr_in to, *addrlist;
-    struct hostent *host, *hostlist;
-    char *cp;
+    struct hostent *host;
     char krbhst[MAX_HSTNM];
     char lrealm[REALM_SZ];
 
@@ -93,24 +90,32 @@ send_to_kdc(KTEXT pkt, KTEXT rpkt, char *realm)
 	(void) strcpy(lrealm, realm);
     else
 	if (krb_get_lrealm(lrealm,1)) {
+#ifndef KRB_NDEB
 	    if (krb_debug)
 		fprintf(stderr, "%s: can't get local realm\n", prog);
+#endif
 	    return(SKDC_CANT);
 	}
+#ifndef KRB_NDEB
     if (krb_debug)
       fprintf(stderr, "lrealm is %s\n", lrealm);
+#endif
     if (krb_udp_port == 0) {
         register struct servent *sp;
         if ((sp = getservbyname("kerberos","udp")) == 0) {
+#ifndef KRB_NDEB
             if (krb_debug)
                 fprintf(stderr, "%s: Can't get kerberos/udp service\n",
                         prog);
+#endif
             krb_udp_port = htons(KRB_PORT); /* Was return(SKDC_CANT); */
         }
         else
 	    krb_udp_port = sp->s_port;
+#ifndef KRB_NDEB
         if (krb_debug)
 	  fprintf(stderr, "krb_udp_port is %d\n", krb_udp_port);
+#endif
     }
     bzero((char *)&to, S_AD_SZ);
     addrlist = malloc(sizeof(*addrlist));
@@ -118,8 +123,10 @@ send_to_kdc(KTEXT pkt, KTEXT rpkt, char *realm)
     if (addrlist == NULL)
         return (SKDC_CANT);
     if ((f = socket(AF_INET, SOCK_DGRAM, 0)) < 0) {
+#ifndef KRB_NDEB
         if (krb_debug)
             fprintf(stderr,"%s: Can't open socket\n", prog);
+#endif
         return(SKDC_CANT);
     }
     /* from now on, exit through rtn label for cleanup */
@@ -130,15 +137,19 @@ send_to_kdc(KTEXT pkt, KTEXT rpkt, char *realm)
     for (i = 1; krb_get_krbhst(krbhst, lrealm, i) == KSUCCESS; ++i) {
 	char *p;
 
+#ifndef KRB_NDEB
         if (krb_debug) {
 	  fprintf(stderr, "Getting host entry for %s...",krbhst);
 	  /*(void) fflush(stdout);*/
         }
+#endif
         host = gethostbyname(krbhst);
+#ifndef KRB_NDEB
         if (krb_debug) {
 	  fprintf(stderr, "%s.\n",
                    host ? "Got it" : "Didn't get it");
         }
+#endif
         if (!host)
             continue;
         no_host = 0;    /* found at least one */
@@ -156,16 +167,20 @@ send_to_kdc(KTEXT pkt, KTEXT rpkt, char *realm)
             retval = KSUCCESS;
             goto rtn;
         }
+#ifndef KRB_NDEB
         if (krb_debug) {
 	  fprintf(stderr, "Timeout, error, or wrong descriptor\n");
 	  /*(void) fflush(stdout);*/
         }
+#endif
       }
     }
     if (no_host) {
+#ifndef KRB_NDEB
 	if (krb_debug)
 	    fprintf(stderr, "%s: can't find any Kerberos host.\n",
 		    prog);
+#endif
         retval = SKDC_CANT;
         goto rtn;
     }
@@ -196,7 +211,6 @@ send_recv(KTEXT pkt, KTEXT rpkt, int f, struct sockaddr_in *_to,
 	  struct sockaddr_in *addrs, int n_hosts)
 {
     fd_set readfds;
-    register struct hostent *hp;
     struct sockaddr_in from;
     int sin_size;
     int numsent;
@@ -208,6 +222,7 @@ send_recv(KTEXT pkt, KTEXT rpkt, int f, struct sockaddr_in *_to,
     timeout.tv_sec = CLIENT_KRB_TIMEOUT;
     timeout.tv_usec = 0;
 
+#ifndef KRB_NDEB
     if (krb_debug) {
         if (_to->sin_family == AF_INET)
             fprintf(stderr, "Sending message to %s...",
@@ -216,17 +231,22 @@ send_recv(KTEXT pkt, KTEXT rpkt, int f, struct sockaddr_in *_to,
 	  fprintf(stderr, "Sending message...");
         /*(void) fflush(stdout);*/
     }
+#endif
     if ((numsent = sendto(f,(char *)(pkt->dat), pkt->length, 0, 
 			  (struct sockaddr *)_to,
                           S_AD_SZ)) != pkt->length) {
+#ifndef KRB_NDEB
         if (krb_debug)
             fprintf(stderr, "sent only %d/%d\n",numsent, pkt->length);
+#endif
         return 0;
     }
+#ifndef KRB_NDEB
     if (krb_debug) {
       fprintf(stderr, "Sent\nWaiting for reply...");
       /*(void) fflush(stdout);*/
     }
+#endif
     FD_ZERO(&readfds);
     FD_SET(f, &readfds);
     errno = 0;
@@ -234,6 +254,7 @@ send_recv(KTEXT pkt, KTEXT rpkt, int f, struct sockaddr_in *_to,
     /* see if timeout or error or wrong descriptor */
     if (select(f + 1, &readfds, (fd_set *)0, (fd_set *)0, &timeout) < 1
         || !FD_ISSET(f, &readfds)) {
+#ifndef KRB_NDEB
         if (krb_debug) {
 	    long rfds;
 	    bcopy(&readfds, &rfds, sizeof(rfds));
@@ -241,35 +262,46 @@ send_recv(KTEXT pkt, KTEXT rpkt, int f, struct sockaddr_in *_to,
                     rfds);
             perror("");
         }
+#endif
         return 0;
     }
     sin_size = sizeof(from);
     if (recvfrom(f, (char *)(rpkt->dat), sizeof(rpkt->dat), 0,
 		 (struct sockaddr *)&from, &sin_size)
         < 0) {
+#ifndef KRB_NDEB
         if (krb_debug)
             perror("recvfrom");
+#endif
         return 0;
     }
+#ifndef KRB_NDEB
     if (krb_debug) {
       fprintf(stderr, "received packet from %s\n", inet_ntoa(from.sin_addr));
       /*fflush(stdout);*/
     }
+#endif
     for (i = 0; i < n_hosts; ++i) {
 	 if (addrs[i].sin_addr.s_addr == from.sin_addr.s_addr) {
+#ifndef KRB_NDEB
             if (krb_debug) {
 	      fprintf(stderr, "Received it\n");
 	      /*(void) fflush(stdout);*/
             }
+#endif
             return 1;
         }
+#ifndef KRB_NDEB
         if (krb_debug)
             fprintf(stderr,
                     "packet not from %lx\n",
                     (long)addrs[i].sin_addr.s_addr);
+#endif
     }
+#ifndef KRB_NDEB
     if (krb_debug)
         fprintf(stderr, "%s: received packet from wrong host! (%x)\n",
                 "send_to_kdc(send_rcv)", (int)from.sin_addr.s_addr);
+#endif
     return 0;
 }
