@@ -26,7 +26,7 @@ or implied warranty.
 
 #include "krb_locl.h"
 
-RCSID("$Header: /afs/nada.kth.se/src/packages/kth-krb/SourceRepository/krb4/lib/krb/tf_util.c,v 1.4 1996/01/08 16:31:12 d91-jda Exp $");
+RCSID("$Header: /src/packages/kth-krb/SourceRepository/krb4/lib/krb/tf_util.c,v 1.6 1996/03/18 16:32:52 bg Exp $");
 
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -136,7 +136,6 @@ int
 tf_init(char *tf_name, int rw)
 {
     int     wflag;
-    uid_t   me, getuid(void);
     struct stat stat_buf;
     int		i_retry;
 
@@ -154,7 +153,9 @@ tf_init(char *tf_name, int rw)
 	wflag = 1;
 	break;
     default:
+#ifndef KRB_NDEB
 	if (krb_debug) fprintf(stderr, "tf_init: illegal parameter\n");
+#endif
 	return TKT_FIL_ACC;
     }
     if (lstat(tf_name, &stat_buf) < 0)
@@ -248,9 +249,11 @@ tf_init(char *tf_name, int rw)
       }
       for (i_retry = 0; i_retry < TF_LCK_RETRY_COUNT; i_retry++) {
 	if (k_flock(fd, K_LOCK_EX | K_LOCK_NB) < 0) {
+#ifndef KRB_NDEB
 	  if (krb_debug)
 	    fprintf(stderr, "tf_init: retry %d of write lock of `%s'.\n",
 		    i_retry, tf_name);
+#endif
 	  sleep (TF_LCK_RETRY);
 	} else {
 	  return KSUCCESS;		/* all done */
@@ -272,9 +275,11 @@ tf_init(char *tf_name, int rw)
 
     for (i_retry = 0; i_retry < TF_LCK_RETRY_COUNT; i_retry++) {
 	if (k_flock(fd, K_LOCK_SH | K_LOCK_NB) < 0) {
+#ifndef KRB_NDEB
 	  if (krb_debug)
 	    fprintf(stderr, "tf_init: retry %d of read lock of `%s'.\n",
 		    i_retry, tf_name);
+#endif
 	  sleep (TF_LCK_RETRY);
 	} else {
 	  return KSUCCESS;		/* all done */
@@ -346,13 +351,17 @@ int
 tf_get_pname(char *p)
 {
     if (fd < 0) {
+#ifndef KRB_NDEB
 	if (krb_debug)
 	    fprintf(stderr, "tf_get_pname called before tf_init.\n");
+#endif
 	return TKT_FIL_INI;
     }
     if (tf_gets(p, ANAME_SZ) < 2)	/* can't be just a null */
       {
+#ifndef KRB_NDEB
 	if (krb_debug) fprintf (stderr, "tf_get_pname: pname < 2.\n");
+#endif
 	return TKT_FIL_FMT;
       }
     return KSUCCESS;
@@ -369,8 +378,10 @@ tf_put_pname(char *p)
     unsigned count;
 
     if (fd < 0) {
+#ifndef KRB_NDEB
 	if (krb_debug)
 	    fprintf(stderr, "tf_put_pname called before tf_create.\n");
+#endif
 	return TKT_FIL_INI;
     }
     count = strlen(p)+1;
@@ -393,13 +404,17 @@ int
 tf_get_pinst(char *inst)
 {
     if (fd < 0) {
+#ifndef KRB_NDEB
 	if (krb_debug)
 	    fprintf(stderr, "tf_get_pinst called before tf_init.\n");
+#endif
 	return TKT_FIL_INI;
     }
     if (tf_gets(inst, INST_SZ) < 1)
       {
+#ifndef KRB_NDEB
 	if (krb_debug) fprintf (stderr, "tf_get_pinst: inst_sz < 1.\n");
+#endif
 	return TKT_FIL_FMT;
       }
     return KSUCCESS;
@@ -416,8 +431,10 @@ tf_put_pinst(char *inst)
     unsigned count;
 
     if (fd < 0) {
+#ifndef KRB_NDEB
 	if (krb_debug)
 	    fprintf(stderr, "tf_put_pinst called before tf_create.\n");
+#endif
 	return TKT_FIL_INI;
     }
     count = strlen(inst)+1;
@@ -444,17 +461,23 @@ tf_get_cred(CREDENTIALS *c)
     int     k_errno;
 
     if (fd < 0) {
+#ifndef KRB_NDEB
 	if (krb_debug)
 	    fprintf(stderr, "tf_get_cred called before tf_init.\n");
+#endif
 	return TKT_FIL_INI;
     }
     if ((k_errno = tf_gets(c->service, SNAME_SZ)) < 2)
 	switch (k_errno) {
 	case TOO_BIG:
+#ifndef KRB_NDEB
 	  if (krb_debug) fprintf (stderr, "tf_get_cred: too big service cred.\n");
+#endif
 	case 1:		/* can't be just a null */
 	  tf_close();
+#ifndef KRB_NDEB
 	  if (krb_debug) fprintf (stderr, "tf_get_cred: null service cred.\n");
+#endif
 	  return TKT_FIL_FMT;
 	case 0:
 	  return EOF;
@@ -462,7 +485,9 @@ tf_get_cred(CREDENTIALS *c)
     if ((k_errno = tf_gets(c->instance, INST_SZ)) < 1)
 	switch (k_errno) {
 	case TOO_BIG:
+#ifndef KRB_NDEB
 	  if (krb_debug) fprintf (stderr, "tf_get_cred: too big instance cred.\n");
+#endif
 	  return TKT_FIL_FMT;
 	case 0:
 	  return EOF;
@@ -470,10 +495,14 @@ tf_get_cred(CREDENTIALS *c)
     if ((k_errno = tf_gets(c->realm, REALM_SZ)) < 2)
 	switch (k_errno) {
 	case TOO_BIG:
+#ifndef KRB_NDEB
 	  if (krb_debug) fprintf (stderr, "tf_get_cred: too big realm cred.\n");
+#endif
 	case 1:		/* can't be just a null */
 	  tf_close();
+#ifndef KRB_NDEB
 	  if (krb_debug) fprintf (stderr, "tf_get_cred: null realm cred.\n");
+#endif
 	  return TKT_FIL_FMT;
 	case 0:
 	  return EOF;
@@ -490,7 +519,9 @@ tf_get_cred(CREDENTIALS *c)
 	tf_read((char *) &(c->issue_date), sizeof(c->issue_date)) < 1
 	) {
 	tf_close();
+#ifndef KRB_NDEB
 	if (krb_debug) fprintf (stderr, "tf_get_cred: failed tf_read.\n");
+#endif
 	return TKT_FIL_FMT;
     }
 #ifdef TKT_SHMEM
@@ -552,8 +583,10 @@ tf_gets(register char *s, int n)
     register count;
 
     if (fd < 0) {
+#ifndef KRB_NDEB
 	if (krb_debug)
 	    fprintf(stderr, "tf_gets called before tf_init.\n");
+#endif
 	return TKT_FIL_INI;
     }
     for (count = n - 1; count > 0; --count) {
@@ -640,8 +673,10 @@ tf_save_cred(char *service, char *instance, char *realm, unsigned char *session,
 #endif /* TKT_SHMEM */
 
     if (fd < 0) {		/* fd is ticket file as set by tf_init */
+#ifndef KRB_NDEB
 	  if (krb_debug)
 	      fprintf(stderr, "tf_save_cred called before tf_init.\n");
+#endif
 	  return TKT_FIL_INI;
     }
     /* Find the end of the ticket file */
