@@ -9,7 +9,7 @@
 #include "config.h"
 #include "protos.h"
 
-RCSID("$Header: /afs/nada.kth.se/src/packages/kth-krb/SourceRepository/krb4/server/kerberos.c,v 1.16 1996/02/09 23:13:45 assar Exp $");
+RCSID("$Header: /src/packages/kth-krb/SourceRepository/krb4/server/kerberos.c,v 1.21 1996/03/24 06:58:04 assar Exp $");
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -445,7 +445,7 @@ kerberos(int f, struct sockaddr_in *client, KTEXT pkt)
 	    bcopy(pkt->dat, auth->dat, auth->length);
 
 	    strncpy(tktrlm, (char *)auth->dat + 3, REALM_SZ);
-	    if (set_tgtkey(tktrlm)) {
+	    if (kerno = set_tgtkey(tktrlm)) {
 		lt = klog(L_ERR_UNK,
 		    "FAILED realm %s unknown. Host: %s ",
 			  tktrlm, inet_ntoa(client_host));
@@ -457,7 +457,7 @@ kerberos(int f, struct sockaddr_in *client, KTEXT pkt)
 
 	    if (kerno) {
 		klog(L_ERR_UNK, "FAILED krb_rd_req from %s: %s",
-		     inet_ntoa(client_host), krb_err_txt[kerno]);
+		     inet_ntoa(client_host), krb_get_err_text(kerno));
 		kerb_err_reply(f, client, pkt, kerno, "krb_rd_req failed");
 		return;
 	    }
@@ -609,20 +609,6 @@ static void check_db_age(void)
     }
 }
 
-static int
-k_getportbyname (const char *service, const char *proto, int default_port)
-{
-    struct servent *sp;
-
-    if ((sp = getservbyname (service, proto)) == NULL) {
-	 fprintf (stderr, "%s: %s/%s unknown service, "
-		  "using default port %d\n", progname, service, proto,
-		  ntohs(default_port));
-	 return default_port;
-    } else
-	 return sp->s_port;
-}
-
 static int
 mksocket(struct in_addr addr, const char *service, int port)
 {
@@ -634,7 +620,8 @@ mksocket(struct in_addr addr, const char *service, int port)
 	fprintf(stderr, "%s: Can't open socket\n", progname);
 	exit(1);
     }
-    if (setsockopt(sock, SOL_SOCKET, SO_REUSEADDR, &on, sizeof(on)) < 0)
+    if (setsockopt(sock, SOL_SOCKET, SO_REUSEADDR, (void *)&on,
+		   sizeof(on)) < 0)
 	fprintf(stderr, "%s: setsockopt (SO_REUSEADDR)\n", progname);
     bzero(&sina, sizeof(sina));
     sina.sin_family = AF_INET;
@@ -655,7 +642,6 @@ process (int sock)
     int n;
     static KTEXT_ST pkt_st;
     KTEXT   pkt = &pkt_st;
-    int     kerror;
 
     fromlen = S_AD_SZ;
     n = recvfrom(sock, pkt->dat, MAX_PKT_LEN, 0, (struct sockaddr *)&from,
@@ -890,7 +876,6 @@ main(int argc, char **argv)
     }
     /* receive loop */
     for (;;) {
-        int sock;
 	int ret;
         fd_set readfds;
 
