@@ -19,7 +19,7 @@ provided "as is" without express or implied warranty.
 
 #include "slav_locl.h"
 
-RCSID("$Header: /afs/nada.kth.se/src/packages/kth-krb/SourceRepository/krb4/slave/kprop.c,v 1.8 1995/11/12 20:22:20 d91-jda Exp $");
+RCSID("$Header: /src/packages/kth-krb/SourceRepository/krb4/slave/kprop.c,v 1.10 1996/03/11 09:22:12 bg Exp $");
 
 #include "kprop.h"
 
@@ -241,7 +241,7 @@ prop_to_slaves(struct slave_host *sl, int fd, char *fslv)
 		    if (kerror != INTK_OK) {
 			fprintf (stderr,
 				 "%s: %s.  While getting initial ticket\n",
-				 cs->name, krb_err_txt[kerror]);
+				 cs->name, krb_get_err_text(kerror));
 			close (s);
 			goto punt;
 		    }
@@ -250,7 +250,7 @@ prop_to_slaves(struct slave_host *sl, int fd, char *fslv)
 		}
 		if (kerror != MK_AP_OK) {
 		    fprintf (stderr, "%s: %s. Calling krb_mk_req.",
-			     cs->name, krb_err_txt[kerror]);
+			     cs->name, krb_get_err_text(kerror));
 		    close (s);
 		    continue;	/*** NEXT SLAVE ***/
 		}		    
@@ -276,7 +276,7 @@ prop_to_slaves(struct slave_host *sl, int fd, char *fslv)
 				       cs->realm, &cred);
 		if (kerror != KSUCCESS) {
 		    fprintf (stderr, "%s: %s.  Getting session key.", 
-			     cs->name, krb_err_txt[kerror]);
+			     cs->name, krb_get_err_text(kerror));
 		    close (s);
 		    continue;	/*** NEXT SLAVE ***/
 		}
@@ -319,7 +319,7 @@ prop_to_slaves(struct slave_host *sl, int fd, char *fslv)
 				      KPROP_PROT_VERSION);
 		if (kerror != KSUCCESS) {
 		    fprintf (stderr, "%s: %s.  Calling krb_sendauth.", 
-			     cs->name, krb_err_txt[kerror]);
+			     cs->name, krb_get_err_text(kerror));
 		    close (s);
 		    continue;	/*** NEXT SLAVE ***/
 		}
