@@ -24,7 +24,7 @@ provided "as is" without express or implied warranty.
 
 #include "slav_locl.h"
 
-RCSID("$Header: /afs/nada.kth.se/src/packages/kth-krb/SourceRepository/krb4/slave/kpropd.c,v 1.11 1995/12/07 13:06:00 assar Exp $");
+RCSID("$Header: /src/packages/kth-krb/SourceRepository/krb4/slave/kpropd.c,v 1.13 1996/03/11 09:22:14 bg Exp $");
 
 #include "kprop.h"
 
@@ -106,7 +106,7 @@ recv_auth (int in, int out, int private, struct sockaddr_in *remote, struct sock
     if (kerror != KSUCCESS) {
       sprintf (errmsg, "kpropd: %s: %s",
 	       private ? "krb_rd_priv" : "krb_rd_safe",
-	       krb_err_txt[kerror]);
+	       krb_get_err_text(kerror));
       klog (L_KRB_PERR, errmsg);
       SlowDeath();
     }
@@ -229,7 +229,7 @@ main(int argc, char **argv)
     kerror = krb_get_lrealm(my_realm,1);
     if (kerror != KSUCCESS) {
       sprintf (errmsg, "kpropd: Can't get local realm. %s",
-	       krb_err_txt[kerror]);
+	       krb_get_err_text(kerror));
       klog (L_KRB_PERR, errmsg);
       SlowDeath();
     }
@@ -316,7 +316,7 @@ main(int argc, char **argv)
 			  version);
     if (kerror != KSUCCESS) {
       sprintf (errmsg, "kpropd: %s: Calling getkdata", 
-	       krb_err_txt[kerror]);
+	       krb_get_err_text(kerror));
       klog (L_KRB_PERR, errmsg);
       SlowDeath();
     }
