@@ -1,6 +1,6 @@
 /*
- * $Header: /afs/nada.kth.se/src/packages/kth-krb/SourceRepository/krb4/util/et/error_message.c,v 1.3 1996/02/06 21:37:55 bg Exp $
- * $Source: /afs/nada.kth.se/src/packages/kth-krb/SourceRepository/krb4/util/et/error_message.c,v $
+ * $Header: /src/packages/kth-krb/SourceRepository/krb4/util/et/error_message.c,v 1.4 1996/03/10 15:12:45 assar Exp $
+ * $Source: /src/packages/kth-krb/SourceRepository/krb4/util/et/error_message.c,v $
  * $Locker:  $
  *
  * Copyright 1987 by the Student Information Processing Board
@@ -21,7 +21,7 @@
 
 #if 0
 static const char rcsid[] =
-    "$Id: error_message.c,v 1.3 1996/02/06 21:37:55 bg Exp $";
+    "$Id: error_message.c,v 1.4 1996/03/10 15:12:45 assar Exp $";
 static const char copyright[] =
     "Copyright 1986, 1987, 1988 by the Student Information Processing Board\nand the department of Information Systems\nof the Massachusetts Institute of Technology";
 #endif
@@ -49,8 +49,7 @@ strerror(int err)
 	
 #endif /* HAVE_STRERROR */
 
-const char * error_message (code)
-long	code;
+const char * error_message (long code)
 {
     int offset;
     struct et_list *et;
