@@ -1,6 +1,6 @@
 /*
- * $Header: /afs/nada.kth.se/src/packages/kth-krb/SourceRepository/krb4/util/et/init_et.c,v 1.3 1996/02/07 10:48:50 d91-jda Exp $
- * $Source: /afs/nada.kth.se/src/packages/kth-krb/SourceRepository/krb4/util/et/init_et.c,v $
+ * $Header: /src/packages/kth-krb/SourceRepository/krb4/util/et/init_et.c,v 1.4 1996/03/10 15:12:46 assar Exp $
+ * $Source: /src/packages/kth-krb/SourceRepository/krb4/util/et/init_et.c,v $
  * $Locker:  $
  *
  * Copyright 1986, 1987, 1988 by MIT Information Systems and
@@ -17,8 +17,9 @@
 #include <errno.h>
 #include "error_table.h"
 #include "mit-sipb-copyright.h"
+#include "internal.h"
 
-RCSID("$Header: /afs/nada.kth.se/src/packages/kth-krb/SourceRepository/krb4/util/et/init_et.c,v 1.3 1996/02/07 10:48:50 d91-jda Exp $");
+RCSID("$Header: /src/packages/kth-krb/SourceRepository/krb4/util/et/init_et.c,v 1.4 1996/03/10 15:12:46 assar Exp $");
 
 struct foobar {
     struct et_list etl;
