@@ -15,7 +15,7 @@
 
 #ifndef lint
 static char const rcsid[] =
-    "$Header: /afs/nada.kth.se/src/packages/kth-krb/SourceRepository/krb4/util/ss/execute_cmd.c,v 1.3 1996/02/07 10:48:54 d91-jda Exp $";
+    "$Header: /src/packages/kth-krb/SourceRepository/krb4/util/ss/execute_cmd.c,v 1.4 1996/03/10 15:12:48 assar Exp $";
 #endif
 
 char **ss_parse (int sci_idx, char *line_ptr, int *argc_ptr);
@@ -139,9 +139,8 @@ static int really_execute_command (int sci_idx, int argc, char ***argv)
  * Notes:
  */
 
-ss_execute_command(sci_idx, argv)
-	int sci_idx;
-	register char *argv[];
+int
+ss_execute_command(int sci_idx, char *argv[])
 {
 	register int i, argc;
 	char **argp;
