@@ -1,7 +1,7 @@
 /*
  * Listener loop for subsystem library libss.a.
  *
- *	$Header: /afs/nada.kth.se/src/packages/kth-krb/SourceRepository/krb4/util/ss/listen.c,v 1.5 1996/02/11 16:06:53 assar Exp $
+ *	$Header: /src/packages/kth-krb/SourceRepository/krb4/util/ss/listen.c,v 1.6 1996/03/10 15:12:52 assar Exp $
  *	$Locker:  $
  * 
  * Copyright 1987, 1988 by MIT Student Information Processing Board
@@ -29,7 +29,7 @@
 
 #ifndef	lint
 static char const rcs_id[] =
-    "$Header: /afs/nada.kth.se/src/packages/kth-krb/SourceRepository/krb4/util/ss/listen.c,v 1.5 1996/02/11 16:06:53 assar Exp $";
+    "$Header: /src/packages/kth-krb/SourceRepository/krb4/util/ss/listen.c,v 1.6 1996/03/10 15:12:52 assar Exp $";
 #endif
 
 static ss_data *current_info;
@@ -64,7 +64,6 @@ int ss_listen (int sci_idx)
     register char *cp;
     register ss_data *info;
     char input[BUFSIZ];
-    char expanded_input[BUFSIZ];
     char buffer[BUFSIZ];
     char *end = buffer;
     int code;
@@ -178,7 +177,7 @@ void ss_abort_subsystem(int sci_idx, int code)
     
 }
 
-void ss_quit(int argc, char **argv, int sci_idx, pointer infop)
+void ss_quit(int argc, char **argv, int sci_idx, void *infop)
 {
     ss_abort_subsystem(sci_idx, 0);
 }
