@@ -1,7 +1,7 @@
 /*
  * prompt.c: Routines for retrieving and setting a prompt.
  *
- * $Header: /afs/nada.kth.se/src/packages/kth-krb/SourceRepository/krb4/util/ss/prompt.c,v 1.2 1996/02/07 10:49:06 d91-jda Exp $
+ * $Header: /src/packages/kth-krb/SourceRepository/krb4/util/ss/prompt.c,v 1.3 1996/03/10 15:12:54 assar Exp $
  * $Locker:  $
  *
  * Copyright 1987, 1988 by MIT Student Information Processing Board
@@ -14,16 +14,14 @@
 #include "ss_internal.h"
 
 static const char rcsid[] =
-    "$Header: /afs/nada.kth.se/src/packages/kth-krb/SourceRepository/krb4/util/ss/prompt.c,v 1.2 1996/02/07 10:49:06 d91-jda Exp $";
+    "$Header: /src/packages/kth-krb/SourceRepository/krb4/util/ss/prompt.c,v 1.3 1996/03/10 15:12:54 assar Exp $";
 
 void ss_set_prompt(int sci_idx, char *new_prompt)
 {
      ss_info(sci_idx)->prompt = new_prompt;
 }
 
-char *
-ss_get_prompt(sci_idx)
-     int sci_idx;
+char *ss_get_prompt(int sci_idx)
 {
      return(ss_info(sci_idx)->prompt);
 }
